/***************************************************************************
                          errorlog.cpp  -  description
                             -------------------
    begin                : Tue Aug 27 2002
    copyright            : (C) 2001 by Ivica Bukvic
    email                : ico@fuse.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "errorlog.h"
#include "rtmix.h"
#include "settings.h"

#include <qtextbrowser.h>
#include <qpushbutton.h>
#include <qlayout.h>
#include <qvariant.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qtimer.h>
#include <qlabel.h>
#include <qlineedit.h>

/* 
 *  Constructs a TextWindow which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 */
TextWindow::TextWindow( QWidget* parent,  RTMix *pointer, const char* name, WFlags fl )
    : ConsoleWindow( parent, name, fl )
{
    if ( !name )
    setName( "RTMix Console" );
    resize( 310, 500 );
    cg.setColor( QColorGroup::Foreground, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Button, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 247, 247, 247) );
    cg.setColor( QColorGroup::Dark, QColor( 119, 119, 119) );
    cg.setColor( QColorGroup::Mid, QColor( 159, 159, 159) );
    cg.setColor( QColorGroup::Text, QColor( 255, 255, 255) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, black );
    cg.setBrush( QColorGroup::Background, QBrush( white, NULL ) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 152, 167, 201) );
    cg.setColor( QColorGroup::HighlightedText, white );
    pal.setActive( cg );
    pal.setInactive( cg );
    pal.setDisabled( cg );
    MultiLineEdit->setPalette( pal );
    QToolTip::add(  (QWidget*) MultiLineEdit, tr( "Console window" ) );
    QWhatsThis::add(  (QWidget*) MultiLineEdit, tr( "Console shows different compile-time and run-time messages, including errors, warnings, and notifications." ) );
    QToolTip::add( (QWidget*) MonitorGroup, tr( "Monitoring LED's" ) );
    QWhatsThis::add( (QWidget*) MonitorGroup, tr( "List of events that are currently being logged in the console." ) );
    QToolTip::add( (QWidget*) ActivityGroup, tr( "Activity LED's" ) );
    QWhatsThis::add( (QWidget*) ActivityGroup, tr( "Activity monitor with a list of events that are currenty occurring, as well as the trigger LED's that notify the user of console warnings and errors." ) );
    
    ARt = new QTimer();
    AOsc = new QTimer();
    AMidi = new QTimer();
    AKeys = new QTimer();
    ANetI = new QTimer();
    ANetO = new QTimer();
    connect( ARt, SIGNAL(timeout()), this, SLOT(TurnARtOff()) );
    connect( AOsc, SIGNAL(timeout()), this, SLOT(TurnAOscOff()) );
    connect( AMidi, SIGNAL(timeout()), this, SLOT(TurnAMidiOff()) );
    connect( AKeys, SIGNAL(timeout()), this, SLOT(TurnAKeysOff()) );
    connect( ANetI, SIGNAL(timeout()), this, SLOT(TurnANetIOff()) );
    connect( ANetO, SIGNAL(timeout()), this, SLOT(TurnANetOOff()) );

    Play = ActivityPlayback->palette().copy();
    ptr = pointer;
    PlaybackBlink = 0;
    PlaybackVal = 0;
    startTimer(1000);
}

/*  
 *  Destroys the object and frees any allocated resources
 */
TextWindow::~TextWindow()
{
    // no need to delete child widgets, Qt does it all for us
}

bool TextWindow::event( QEvent* ev )
{
    bool ret = QWidget::event( ev );
    if ( ev->type() == QEvent::Hide )
    {
        emit Closed( 0 );
    }
    return ret;
}

void TextWindow::run()
{
    while( 1 )
    {
        usleep( 10 );
    }
}

void TextWindow::timerEvent( QTimerEvent *e )
{
    //qDebug("HERE");
    if ( PlaybackVal > 0 )
    {
        //qDebug("Yes");
        QColor c = ActivityPlayback->palette().color( QPalette::Active, QColorGroup::Base );
        if ( PlaybackBlink == 0 )
        {
            //qDebug("0");
            PlaybackBlink = 1;
            c = c.light( 80 );
        }
        else
        {
            //qDebug("1");
            PlaybackBlink = 0;
            c = c.light( 125 );
        }
        Play.setColor( QPalette::Active, QColorGroup::Base, c  );
        Play.setColor( QPalette::Inactive, QColorGroup::Base, c );
        ActivityPlayback->setPalette( Play );
    }
}

void TextWindow::AddText( QString s )
{
    MultiLineEdit->append( s );
    MultiLineEdit->scrollToBottom();
}

void TextWindow::Clear()
{
	MultiLineEdit->setText( "" );
}

void TextWindow::keyPressEvent ( QKeyEvent *k )
{
    emit KeyPress( k );
}

void TextWindow::keyReleaseEvent ( QKeyEvent *k )
{
    emit KeyRelease( k );
}

void TextWindow::closeEvent ( QCloseEvent * )
{
    AddText( "Console window cannot be closed. If you need to remove it from the screen, you may want to simply minimize it.\n" );
}

void TextWindow::ToggleMRt( bool b )
{
    if ( b )
    {
        MonitorRT->setPaletteBackgroundColor( QColor(0, 255, 0) );
    }
    else
    {
        MonitorRT->setPaletteBackgroundColor( QColor(170, 0, 0) );
    }
}

void TextWindow::ToggleMMidi( bool b )
{
    if ( b )
    {
        MonitorMidi->setPaletteBackgroundColor( QColor(0, 255, 0) );
    }
    else
    {
        MonitorMidi->setPaletteBackgroundColor( QColor(170, 0, 0) );
    }
}

void TextWindow::ToggleMVerbose( bool b )
{
    if ( b )
    {
        MonitorVerbose->setPaletteBackgroundColor( QColor(0, 255, 0) );
    }
    else
    {
        MonitorVerbose->setPaletteBackgroundColor( QColor(170, 0, 0) );
    }
}

void TextWindow::ToggleMMidiLog( bool b )
{
    if ( b )
    {
        MonitorMidiLog->setPaletteBackgroundColor( QColor(0, 255, 0) );
    }
    else
    {
        MonitorMidiLog->setPaletteBackgroundColor( QColor(170, 0, 0) );
    }
}

void TextWindow::ToggleMNet( bool b )
{
    if ( b )
    {
        MonitorNet->setPaletteBackgroundColor( QColor(0, 255, 0) );
    }
    else
    {
        MonitorNet->setPaletteBackgroundColor( QColor(170, 0, 0) );
    }
}

void TextWindow::ToggleMNetHost( bool b )
{
    if ( b )
    {
        MonitorNetHost->setPaletteBackgroundColor( QColor(0, 255, 0) );
    }
    else
    {
        MonitorNetHost->setPaletteBackgroundColor( QColor(170, 0, 0) );
    }
}

void TextWindow::ToggleARt( bool b )
{
    if ( b )
    {
        ARt->changeInterval( 100 );
        ActivityRt->setPaletteBackgroundColor( QColor(255, 255, 0) );
    }
    else
    {
        ActivityRt->setPaletteBackgroundColor( QColor(107, 107, 107) );
    }
}

void TextWindow::ToggleAOsc( bool b )
{
    if ( b )
    {
        AOsc->changeInterval( 100 );
        ActivityOsc->setPaletteBackgroundColor( QColor(255, 255, 0) );
    }
    else
    {
        ActivityOsc->setPaletteBackgroundColor( QColor(107, 107, 107) );
    }
}

void TextWindow::ToggleAMidi( bool b )
{
    if ( b )
    {
        AMidi->changeInterval( 100 );
        ActivityMidi->setPaletteBackgroundColor( QColor(255, 255, 0) );
    }
    else
    {
        ActivityMidi->setPaletteBackgroundColor( QColor(107, 107, 107) );
    }
}

void TextWindow::ToggleAKeys( bool b )
{
    if ( b )
    {
        AKeys->changeInterval( 100 );
        ActivityKeys->setPaletteBackgroundColor( QColor(255, 255, 0) );
    }
    else
    {
        ActivityKeys->setPaletteBackgroundColor( QColor(107, 107, 107) );
    }
}

void TextWindow::ToggleANetI( bool b )
{
    if ( b )
    {
        ANetI->changeInterval( 100 );
        ActivityNetI->setPaletteBackgroundColor( QColor(255, 255, 0) );
    }
    else
    {
        ActivityNetI->setPaletteBackgroundColor( QColor(107, 107, 107) );
    }
}

void TextWindow::ToggleANetO( bool b )
{
    if ( b )
    {
        ANetO->changeInterval( 100 );
        ActivityNetO->setPaletteBackgroundColor( QColor(255, 255, 0) );
    }
    else
    {
        ActivityNetO->setPaletteBackgroundColor( QColor(107, 107, 107) );
    }
}

void TextWindow::ToggleAWarns( bool b )
{
    if ( b )
    {
        ActivityWarns->setPaletteBackgroundColor( QColor(255, 170, 0) );
    }
    else
    {
        ActivityWarns->setPaletteBackgroundColor( QColor(107, 107, 107) );
    }
}

void TextWindow::ToggleAErrors( bool b )
{
    if ( b )
    {
        ActivityErrors->setPaletteBackgroundColor( QColor(250, 0, 0) );
    }
    else
    {
        ActivityErrors->setPaletteBackgroundColor( QColor(107, 107, 107) );
    }
}

void TextWindow::ToggleAPlay( int i )
{
    PlaybackBlink = 0;
    PlaybackVal = i;
    if ( i == 0 )
    {
        ActivityPlayback->setText( "Stopped" );
        Play.setColor( QPalette::Active, QColorGroup::Base, QColor( 107, 107, 107 ) );
        Play.setColor( QPalette::Inactive, QColorGroup::Base, QColor( 107, 107, 107 ) );
        ActivityPlayback->setPalette( Play );
    }
    else if ( i == 3 )
    {
        ActivityPlayback->setText( "Paused" );
        Play.setColor( QPalette::Active, QColorGroup::Base, QColor( 255, 255, 0 ) );
        Play.setColor( QPalette::Inactive, QColorGroup::Base, QColor( 255, 255, 0 ) );
        ActivityPlayback->setPalette( Play );
    }
    else
    {
        ActivityPlayback->setText( "Playing" );
        Play.setColor( QPalette::Active, QColorGroup::Base, QColor( 255, 0, 0 ) );
        Play.setColor( QPalette::Inactive, QColorGroup::Base, QColor( 255, 0, 0 ) );
        ActivityPlayback->setPalette( Play );
    }
}

void TextWindow::TurnARtOff()
{
    ToggleARt( FALSE );
}

void TextWindow::TurnAOscOff()
{
    ToggleAOsc( FALSE );
}

void TextWindow::TurnAMidiOff()
{
    ToggleAMidi( FALSE );
}

void TextWindow::TurnAKeysOff()
{
    ToggleAKeys( FALSE );
}

void TextWindow::TurnANetIOff()
{
    ToggleANetI( FALSE );
}

void TextWindow::TurnANetOOff()
{
    ToggleANetO( FALSE );
}

void TextWindow::Post( QString s, bool Verbose, int PlaybackStatus, bool CompileFlag, bool RTEB, bool MIDIL,
    long TimeCount, long AbsTimeCount )
{
    //qDebug( "Play: %d", PlaybackStatus);
    if ( Verbose && PlaybackStatus > 0 || Verbose && RTEB || s.lower().find("midi",0) != -1 && MIDIL ||
        s.lower().find("error",0) != -1 || s.find(":|",0) == 0 || PlaybackStatus == 0 && !RTEB || s.startsWith(" ++ ") )
    {
        if ( s.startsWith(" -- ") || s.startsWith(" ++ ") )
        {               
            long temp;
            QString value, digits;

            temp = TimeCount;
            value = "r:";
            value = value + digits.setNum( (temp/360000), 10 );
            temp = temp - ((temp/360000) * 360000);
            value = value + ":" + digits.setNum( (temp/6000), 10 );
            temp = temp - ((temp/6000) * 6000 );
            value = value + ":" + digits.setNum ( (temp/100), 10 );
            temp = temp - ((temp/100) * 100 );
            if ( temp < 10 )
            {
                value = value + ".0" + digits.setNum( temp, 10 );
            }
            else
            {
                value = value + "." + digits.setNum( temp, 10 );
            }

            temp = AbsTimeCount;
            value = value + " a:";
            value = value + digits.setNum( (temp/360000), 10 );
            temp = temp - ((temp/360000) * 360000);
            value = value + ":" + digits.setNum( (temp/6000), 10 );
            temp = temp - ((temp/6000) * 6000 );
            value = value + ":" + digits.setNum ( (temp/100), 10 );
            temp = temp - ((temp/100) * 100 );
            if ( temp < 10 )
            {
                value = value + ".0" + digits.setNum( temp, 10 );
            }
            else
            {
                value = value + "." + digits.setNum( temp, 10 );
            }
            s = value + s;         
        }
        if ( s.lower().find("error", 0) != -1 && s.lower().find("errors", 0 ) == -1 && s.lower().find("file ",0) == -1 ) //show-stoppers
        {
            ToggleAErrors( TRUE );
            s.insert( 0, "<font color=\"#ff0000\">" );
            s.append( "</font>" );
            if ( CompileFlag == TRUE && s.lower().find("osc ", 0 ) == -1 )
            {
                CompileFlag = FALSE;
            }
            if ( s.lower().find("midi",0) != -1 && s.lower().find("file ",0) == -1 )
            {
                ptr->S->MidiStatus->setText("Status: OFF");
                if ( ptr->MIDIEventButton->isOn() )
                {
                    ptr->MIDIEventButton->setOn( FALSE );
                }
            }
        }
        else if ( s.lower().find("warning:", 0) != -1 && s.lower().find("file ",0) == -1 ) //warnings
        {
            ToggleAWarns( TRUE );
            s.insert( 0, "<font color=\"#ffa000\">" );
            s.append( "</font>" );
        }
        else if ( s.lower().find("midi", 0) != -1 && s.lower().find("file ",0) == -1 ) //Midi issues
        {
            s.insert( 0, "<font color=\"#e8bfff\">" );
            s.append( "</font>" );
        }
        else if ( CompileFlag == TRUE ) //when compiling
        {
            s.insert( 0, "<font color=\"#ffff00\">" );
            s.append( "</font>" );
        }
        else if ( s.lower().find("--", 0) != -1 && s.lower().find("file ",0) == -1 || s.lower().find("++", 0) != -1 && s.lower().find("file ",0) == -1 ) //real-time stuff
        {
            //ErrorLog->setColor( QColor( 85, 255, 0 ) );
            //T->MultiLineEdit->setColor( QColor( 85, 255, 0 ) );
            s.insert( 0, "<font color=\"#55ff00\">" );
            s.append( "</font>" );
        }
        else if ( s.find(":|", 0) != -1 && s.lower().find("file ",0) == -1 ) //Transport control log
        {
            s.insert( 0, "<font color=\"#82c8ff\"><b>" );
            s.append( "</font></b>" );
            //qDebug( "Play2: %i", PlaybackStatus);
            /*
            if ( s.find("ST") != -1 || s.find("PAN") != -1 || s.find("RESE") != -1 )
            {
                ToggleAPlay( 0 );
            }
            if ( s.find("PAU") != -1 )
            {
                ToggleAPlay( 3 );
            }
            if ( s.find("PL") != -1 || s.find("RESU") != -1 )
            {
                ToggleAPlay( 4 );
            }
            */
        }

    //ErrorLog->append( s );
    //ErrorLog->scrollToBottom();

    AddText( s );
    }
    //qDebug( "Flag: %d", CompileFlag );
}
