/***************************************************************************
                          oscevent.h  -  description
                             -------------------
    begin                : Tue Feb 11 2003
    copyright            : (C) 2003 by Ivica Bukvic
    email                : ico@fuse.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

/**
  *@author Ivica Bukvic
  */

/* OSC License
Copyright (c) 1996,1997.  The Regents of the University of California (Regents).
All Rights Reserved.

Permission to use, copy, modify, and distribute this software and its
documentation for educational, research, and not-for-profit purposes, without
fee and without a signed licensing agreement, is hereby granted, provided that
the above copyright notice, this paragraph and the following two paragraphs
appear in all copies, modifications, and distributions.  Contact The Office of
Technology Licensing, UC Berkeley, 2150 Shattuck Avenue, Suite 510, Berkeley,
CA 94720-1620, (510) 643-7201, for commercial licensing opportunities.

Written by Matt Wright, The Center for New Music and Audio Technologies,
University of California, Berkeley.

     IN NO EVENT SHALL REGENTS BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT,
     SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS,
     ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF
     REGENTS HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

     REGENTS SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT
     LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
     FOR A PARTICULAR PURPOSE. THE SOFTWARE AND ACCOMPANYING
     DOCUMENTATION, IF ANY, PROVIDED HEREUNDER IS PROVIDED "AS IS".
     REGENTS HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES,
     ENHANCEMENTS, OR MODIFICATIONS.
*/
 
#ifndef OSCEVENT_H
#define OSCEVENT_H

#include <qwidget.h>

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <errno.h>
#include <string.h>
#include <sys/time.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <netdb.h>
#include <sys/socket.h>
#include <sys/wait.h>
#include <fcntl.h>

#define EMPTY 0	 /* Nothing written to packet yet */
#define ONE_MSG_ARGS 1 /* Packet has a single message; gathering arguments */
#define NEED_COUNT 2 /* Just opened a bundle; must write message name or open another bundle */
#define GET_ARGS 3 /* Getting arguments to a message. */
#define DONE 4 /* All open bundles have been closed, so can't write  anything else */

#define MAX_BUNDLE_NESTING 32
#define STRING_ALIGN_PAD 4
#define MAX_ARGS 2000
#define SC_BUFFER_SIZE 32000

typedef int int4byte;
typedef unsigned int uint32;
typedef struct OSCbuf_struct {
    char *buffer; /* The buffer to hold the OSC packet */
    int size; /* Size of the buffer */
    char *bufptr; /* Current position as we fill the buffer */
    int state; /* State of partially-constructed message */
    int4byte *thisMsgSize; /* Pointer to count field before currently-being-written message */
    int4byte *prevCounts[MAX_BUNDLE_NESTING]; /* Pointers to count field before each currently open bundle */
    int bundleDepth;  /* How many sub-sub-bundles are we in now? */
    char *typeStringPtr; /* This pointer advances through the type tag string as you add arguments. */
    int gettingFirstUntypedArg;  /* nonzero if this message doesn't have a type tag and we're waiting for the 1st arg */
} OSCbuf;
typedef struct {
    uint32 seconds;
    uint32 fraction;
} OSCTimeTag;
enum type_char {INT, FLOAT, STRING};
typedef struct {
    type_char type;
    union {
        int i;
        float f;
        char *s;
    } datum;
} typedArg;

class OSCEvent : public QObject  {
  Q_OBJECT
public: 
  OSCEvent( QWidget* parent = 0, const char* WidgetName = 0, WFlags fl = 0, const char *host="localhost", int port= 0, bool typetags=FALSE,
          char *msgname= "null", int low_a=128, int high_a=256, int low_b=0, int high_b=127, int low_c=-1, int high_c=127 );
  ~OSCEvent();

  int GetStatus();
  int WriteMessage( char*, int, int );
  int WriteCustomMessage( char* );
  
  char *hostname;
  int portname;
    
private:
  OSCbuf buf[1];
  int sock;
  struct sockaddr_in theiraddr;
  char *tmpBuf;
  bool tags;

  int status;

  int la, ha, lb, hb, lc, hc;

  void OpenSocket();
  void OpenBundle();
  void CloseBundle();
  void SendError( QString );

  int OpenUDPSocket();
  int SendBuf( char * );
  int ParseMessage(OSCbuf *, char *, int , typedArg *);

  void OSC_initBuffer(OSCbuf *, int, char *);
  void OSC_resetBuffer(OSCbuf *);
  int OSC_isBufferEmpty(OSCbuf *);
  int OSC_freeSpaceInBuffer(OSCbuf *);
  int OSC_isBufferDone(OSCbuf *);
  char *OSC_getPacket(OSCbuf *);
  int OSC_packetSize(OSCbuf *);
  void PatchMessageSize(OSCbuf *);
  int OSC_openBundle(OSCbuf *, OSCTimeTag);
  int OSC_closeBundle(OSCbuf *);
  int OSC_closeAllBundles(OSCbuf *);
  int OSC_writeAddress(OSCbuf *, char *);
  int OSC_writeAddressAndTypes(OSCbuf *, char *, char *);
  int CheckTypeTag(OSCbuf *, char );
  int OSC_writeFloatArg(OSCbuf *, float );
  int OSC_writeFloatArgs(OSCbuf *, int, float *);
  int OSC_writeIntArg(OSCbuf *, int4byte );
  int OSC_writeStringArg(OSCbuf *, char *);
  int OSC_effectiveStringLength(char *);
  int OSC_padString(char *, char *);
  int OSC_padStringWithAnExtraStupidComma(char *, char *);
  int OSC_WritePadding(char *, int );
  int CheckOverflow(OSCbuf *, int );

  OSCTimeTag OSCTT_CurrentTime(void);
  OSCTimeTag OSCTT_Immediately(void);
  OSCTimeTag OSCTT_BiggestPossibleTimeTag(void);
  OSCTimeTag OSCTT_PlusSeconds(OSCTimeTag , float );
  int OSCTT_Compare(OSCTimeTag , OSCTimeTag );

  char* QStringToChar( QString );

signals:
  void Error( QString );
};

#endif
