/***************************************************************************
                          qmidi.cpp  -  description
                             -------------------
    begin                : Wed Feb 5 2003
    copyright            : (C) 2003 by Ivica Bukvic
    email                : ico@fuse.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qmidi.h"

#include <fcntl.h>
#include <stdio.h>
#include <unistd.h>
#include <qapplication.h>

QMidi::QMidi(QWidget* parent, const char* name, WFlags fl, QString port)
{
  //connect ( this, SIGNAL ( Error( QString ) ), parent, SLOT ( Error( QString) ) );
  command = -1;
  message_1 = -1;
  message_2 = -1;
  numMidiObjs = -1;
  status = 0;
  midi_fd = 0;
  ptr = parent;

  midi_fd = ::open(port, O_RDWR | O_NONBLOCK);
  //qDebug( "midi_fd = %i", midi_fd );
  /* Open the MIDI port */
  if ( midi_fd == -1)
  {
      //qDebug( port );
      //qDebug( "midi_fd = %i", midi_fd );
      se = new StringEvent( "MIDI Error: Failed opening " + port + ". Port either not present or busy. You can try to enable it by selecting the appropriate device in the settings menu." );
      QApplication::postEvent( ptr, se );
      //emit Error( "MIDI Error: Failed opening midi port. You can try to enable it from the settings menu." );
  }
  else
  {
      ::close(midi_fd);
      midi_fd = ::open(port, O_RDWR);
      //qDebug( "midi_fd = %i", midi_fd );
      se = new StringEvent( "MIDI port " + port + " opened." );
      QApplication::postEvent( ptr, se );
      //emit Error( "MIDI port opened." );
  }
  MidiLog = false;
}

QMidi::~QMidi()
{
  if ( midi_fd != -1 )
  {
      ::close(midi_fd);
  }
}

int QMidi::RetryOpen( QString port )
{
  if ( midi_fd != -1 )
  {
      se = new StringEvent( "Disconnecting MIDI port..." );
      QApplication::postEvent( ptr, se );
      ::close(midi_fd);
  }
  midi_fd = ::open(port, O_RDWR);
  if ( midi_fd == -1)
  {
      se = new StringEvent( "MIDI Error: Failed opening midi port. You can try to enable it by selecting the appropriate device in the settings menu." );
      QApplication::postEvent( ptr, se );
  }
  else
  {
      se = new StringEvent( "MIDI port opened." );
      QApplication::postEvent( ptr, se );
  }
  return midi_fd;
}

void QMidi::run()
{
    unsigned char datum;
    int check;
    QString a, b, c, send;

    while (TRUE)
    {
        if (status > 0 )
        {
            /* Read in some MIDI data */
            check = ::read(midi_fd, &datum, 1);

            
            if ( check == -1 )
            {
                se = new StringEvent( "MIDI Error: Failed reading MIDI port. Disabling MIDI monitoring." );
                QApplication::postEvent( ptr, se );
                //emit Error("MIDI Error: Failed reading MIDI port. Disabling MIDI thread. You can try to enable it from the settings menu.");
                status = FALSE;
            }
            
            
            //qDebug( "Received: %d", datum );

            //Anything that is system-exclusive is treated as no midi received
            if ( datum >= 0xF0 && command != -1 )
            {
                se = new StringEvent( "*" );
                QApplication::postEvent( ptr, se );
                //emit noMessage();
                command = -1;
                message_1 = -1;
                message_2 = -1;                
            }
            //Let's see what we got
            //regular message value
            else if ( datum < 0x80 )
            {
                //qDebug("Read: %d", datum);
                if ( message_1 == -1 )
                    message_1 = datum;
                else
                {
                    if ( message_2 == -1 && numMidiObjs == 3 )
                        message_2 = datum;
                    else
                    {
                        message_2 = -1;
                        message_1 = datum;
                    }
                }
            }
            //Command values
            else
            {
                //reset the values since this implies new message
                command = datum;
                message_1 = -1;
                message_2 = -1;
                if ( command >= 0x80 && command <= 0xBF || command >= 0xE0 && command <= 0xEF )
                {
                    numMidiObjs = 3;
                }
                else
                {
                    numMidiObjs = 2;
                }
            }
            //SEND COMPLETE PACKAGES
            if ( message_1 != -1 && numMidiObjs == 2  || message_2 != -1 && numMidiObjs == 3 )
            {
                me = new MidiEvent( command, message_1, message_2 );
                QApplication::postEvent( ptr, me );
                if ( MidiLog )
                {
                    send = " -- MIDI: " + a.setNum( command ) + ", " + b.setNum( message_1 );
                    if ( numMidiObjs == 3 )
                    {
                        send = send + ", " + c.setNum( message_2 );
                    }
                    se = new StringEvent( send );
                    QApplication::postEvent( ptr, se );
                }
            }
        }
        else
        {
            usleep(10);
        }
    }
}

int QMidi::Write( unsigned char data )
{
  //qDebug("Received data %d", data );
  if ( status )
  {
    if (::write(midi_fd, &data, 1) == -1)
    {
      se = new StringEvent( "MIDI Error: Failed reading MIDI port. Disabling MIDI monitoring." );
      QApplication::postEvent( ptr, se );
      //emit Error( "MIDI Error: Failed writing to MIDI port. Disabling MIDI thread. You can try to enable it from the settings menu." );
      status = 0;
    }
  }
  return 0;
}

void QMidi::ChangeStatus( bool b )
{
    if ( b )
    {
        se = new StringEvent(" ++ Starting real-time MIDI monitoring...");
        QApplication::postEvent( ptr, se );
        //emit Error( "MIDI real-time events ENABLED." );
    }
    else
    {
        se = new StringEvent(" ++ Stopping real-time MIDI monitoring...");
        QApplication::postEvent( ptr, se );
        //emit Error( "MIDI real-time events DISABLED." );
    }
    status = b;
}

int QMidi::GetCommand()
{
    return command;
}
int QMidi::GetMessage_1()
{
    return message_1;
}
int QMidi::GetMessage_2()
{
    return message_2;
}

bool QMidi::GetStatus()
{
    return status;
}
