/***************************************************************************
                          randfuncs.h  -  description
                             -------------------
    begin                : Tue Aug 6 2002
    copyright            : (C) 2002 by Ivica Bukvic
    email                : ico@fuse.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

//RANDOM FUNCTIONS BORROWED FROM THE RTCmix PROGRAM VERSION 3.1.0

#ifndef RANDFUNCS_H
#define RANDFUNCS_H

#include <math.h>
#include <sys/time.h>

/* rrand() -- modification of unix rand() to return floating point values
   between + and - 1.0 */

float rrand(long randx)
{
	int i = ((randx = randx*1103515245 + 12345)>>16) & 077777;
	return((float)i/16384. - 1.);
}


/* brrand() -- a modification of unix rand() to return floating point values
   between 0.0 and 1..0 */

float brrand(long randx)
{
	int i = ((randx = randx*1103515245 + 12345)>>16) & 077777;
	return((float)i/32768.0);
}


/* tsrand() seeds rrand() and brrand() with time of day */

float tsrand()
{
	struct timeval tv;
	struct timezone tz;

	gettimeofday(&tv,&tz);
	return tv.tv_usec;
}


/* gaussian - gaussian random distribution with fixed boundaries (0-1)
   (by luke) */

float gaussian(long seed)
{
	int j;
	int N = 12; /* number of passes for the gaussian curve */
	int halfN = 6;
	int scale = 1;
	float output;
	float sigma = .166666;
	float mu = .5;
	float randnum;

	randnum = 0.0;
	for(j = 0; j < N; j++) {
		randnum += brrand(seed);
  	}

	output = -1.0;
	while ( (output < 0.0) && (output > 1.0) ) {
		output = sigma*scale*(randnum-halfN)+mu;
	}

	return(output);
}


/* cauchy - cauchy random distribution with fixed boundaries (0-1)
   (by luke) */


float cauchy(long seed)
{
	float alpha = .00628338;
	float pi = 3.1415927;
	float output;
	float randnum;

	output = -1.0;
	while ( (output < 0.0) && (output > 1.0) ) {
		randnum = brrand(seed);
		randnum *= pi;

		output=(alpha*tan(randnum))+0.5;
	}

	return(output);
}


/* linlo() - lower -limit weighted random numbers
   (by luke) */

float linlo(long seed)
{
	float randnum, randnum2;

	randnum = brrand(seed);
	randnum2 = brrand(seed);
	if(randnum2 < randnum) randnum = randnum2;

	return(randnum);
}


/* linhi() - upper-limit weighted random numbers
   (by luke) */

float linhi(long seed)
{
	float randnum, randnum2;

	randnum = brrand(seed);
	randnum2 = brrand(seed);
	if(randnum2 > randnum) randnum = randnum2;

	return(randnum);
}


/* triangle -- triangle-curve of  random numbers between 0 and 1
   (by luke) */

float triangle(long seed)
{
	float randnum, randnum2, output;

	randnum = brrand(seed);
	randnum2 = brrand(seed);
	output = 0.5*(randnum+randnum2);

	return(output);
}

#endif
