/***************************************************************************
                          rtmix-fileio.h  -  description
                             -------------------
    begin                : Wed Dec 5 2001
    copyright            : (C) 2001 by Ivica Bukvic
    email                : ico@fuse.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef RTMIX_FILEIO_H
#define RTMIX_FILEIO_H

void RTMix::AutoOpenFile( QString file )
{
	QString s;
	QFile f( file );
	
	Tabs->setCurrentPage( 1 );

	if ( f.open(IO_ReadOnly) )
	{
		QTextStream t( &f );
		s = t.read();
		Editor->setText( tr( s ) );
		if ( Editor->text() == "" )
		{
         	Error ( "No such file \"" + file + "\". Creating new file...\n" );
		}
		else
		{
			Error( "File \"" + file + "\" successfully opened...\n" );
		}
		compareFile = Editor->text();
		outputFile = file;
	}
	else
	{
	  	Error( "Could not open the file \"" + file + "\". Please check read permissions or if the file exists at all.\n" );
	}	 	
}

int RTMix::RefreshEditor()
{
	Error( "Refreshing file...\n" );
	if ( Editor->text() != compareFile ) { //if the file has not been saved
		switch ( QMessageBox::warning( this, "Refresh", "File stored in the Editor window has been modified. Refresh from file?", "Yes", "No", 0, 1, 1 ) ) {
			case 1:
				return 0;
		}
	}
	if ( outputFile == "0" )
	{
     	Error( "No file to refresh from...\n" );
		return 0;
	}
	Editor->setText("");;
	QFile f( outputFile );
	if ( f.open(IO_ReadOnly) ) {    // file opened successfully
		QTextStream t( &f );        // use a text stream
		QString s;
		s = t.read();
		Editor->setText( tr( s ) );
		Error( "File \"" + outputFile + "\" successfully refreshed...\n" );
		compareFile = Editor->text();
	}	
	return 0;
}

void RTMix::OpenExternEditor()
{
	Error( "Opening external editor...\n");
	if ( outputFile == "0" || Editor->text() != compareFile )
	{
		Error( "Event-script has not been saved. Saving file before opening it with an external editor...\n" );
	}
	SaveFile();
	if ( outputFile == "0" )
	{
     	Error( "Action cancelled...\n" );
	}
	else
	{
		Error( "Executing call for the external editor (this may take a second or two depending on the speed of your computer)...\n");
		system( S->GetEditor() + " " + outputFile + "&" );
		//qDebug( S->GetEditor() + " " + outputFile + "&" );
	}
}

int RTMix::OpenFile()
{
	if ( outputFile == "0" && Editor->text() != "" || Editor->text() != compareFile ) { //if the file has not been saved
		switch ( QMessageBox::warning( this, "Open", "File has not been saved since you modified it. Open new?", "Yes", "No", 0, 1, 1 ) ) {
			case 1:
				return 0;
		}
	}
	QString file( QFileDialog::getOpenFileName( QString::null, "RTMix score files ( *.rmx )", this ) );
    if ( file.isEmpty() ) {
		return 0;
	}
	else {
		inputFile = file;
		outputFile = file;
		QFile f( file );
		if ( f.open(IO_ReadOnly) ) {    // file opened successfully
			QTextStream t( &f );        // use a text stream
			QString s;
			s = t.read();
			Editor->setText( tr( s ) );
			Error( "File \"" + file + "\" successfully opened...\n" );
			compareFile = Editor->text();
          /*
          if ( PlaybackStatus > 0 )
          {
              Stop();
          }
          Stop();
          PurgeCue();
          */
		}
		else
		{
         	QMessageBox::warning ( this, "File Open Failed", "Could not open the file. Please check read permissions.", "OK", 0, 0, 0, 1 );
		}	
	}
	return 0;
}

int RTMix::SaveAsFile()
{
	QString file( QFileDialog::getSaveFileName( QString::null, "RTMix score files ( *.rmx )", this ) );
	if ( file == NULL )
	{
     	return 0;
	}
	if ( file.find( ".rmx", 0, FALSE ) == -1 ) {
        if ( file.endsWith( "." ) )
        {
            file = file + "rmx";
        }
        else if ( file.endsWith( ".r" ) )
        {
            file = file + "mx";
        }
        else if ( file.endsWith( ".rm" ) )
        {
            file = file + "x";
        }
        else
        {
            file = file + ".rmx";
        }
	}
	QFile f( file );
   	if ( f.exists() ) {
		switch ( QMessageBox::warning( this, "File Exists", "File already exists. Overwrite?", "Yes", "No", 0, 1, 1 ) ) {					
			case 1:
				return 0;
		}
	}
	if ( f.open(IO_WriteOnly) ) {    // file opened successfully
		QString o;
		o = Editor->text();
		QTextStream t( &o, IO_ReadOnly );
		outputFile = file;
		inputFile = file;
		QString s;
		while ( !t.eof() ) {
			s = t.readLine();
			f.writeBlock( s + "\n", strlen(s) + 1 );
		}
		f.close();
		QMessageBox::information( this, "Saved", "File Saved." );
		Error( "File \"" + file + "\" successfully saved...\n" );
		compareFile = Editor->text();
	}
	else
	{
         QMessageBox::warning ( this, "File Save Failed", "Could not save the file. Please check write permissions.", "OK", 0, 0, 0, 1 );
	}
	return 0;
}

int RTMix::SaveFile()
{
	if ( outputFile == "0" ) {
		RTMix::SaveAsFile();
		return 0;
	}
	else {
		QFile f( outputFile );
		if ( f.open(IO_WriteOnly) ) {    // file opened successfully
			QString o;
			o = Editor->text();
			QTextStream t( &o, IO_ReadOnly );
			QString s;
			while ( !t.eof() ) {
				s = t.readLine();
				f.writeBlock( s + "\n", strlen(s) + 1 );
			}
			f.close();
			//QMessageBox::information( this, "Saved", "File Saved." );
			Error ( "File successfully saved...\n" );
			compareFile = Editor->text();
    	}
		else
		{
			QMessageBox::warning ( this, "File Save Failed", "Could not save the file. Please check write permissions.", "OK", 0, 0, 0, 1 );
		}	
	}
	return 0;
}

int RTMix::New()
{
	if ( outputFile == "0" && Editor->text() != "" || Editor->text() != compareFile ) { //if the file has not been saved
		switch ( QMessageBox::warning( this, "New", "File has not been saved since you modified it. Create new?", "Yes", "No", 0, 1, 1 ) ) {
			case 1:
				return 0;
		}
	}
	Editor->clear();
	inputFile = "0";
	outputFile = "0";
	compareFile = "";
	Error ( "New file created...\n" );
	return 0;
}

#endif
