/***************************************************************************
                          settings.cpp  -  description
                             -------------------
    begin                : Thu Aug 22 2002
    copyright            : (C) 2002 by Ivica Bukvic
    email                : ico@fuse.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "settings.h"
#include "settingsimages.h"
#include "rtmix.h"

#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qcombobox.h>
#include <qframe.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qtextedit.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <qtabwidget.h>
#include <qlayout.h>                                                                                                                                                                                            
#include <qvariant.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

#include "QLCD.h"
#include "QLED.h"
#include "version.h"
#include "path.h"

/* 
 *  Constructs a settings which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 */
settings::settings( QWidget* parent,  const char* name, WFlags fl, RTMix *ptr )
    : QWidget( parent, name, fl )
{
    QPixmap image0( ( const char** ) image0_data );
    QPixmap image1( ( const char** ) image1_data );
    QPixmap image2( ( const char** ) image2_data );
    QPixmap image3( ( const char** ) image3_data );
   // QPixmap image4( ( const char** ) image4_data );
    QPixmap image4;
	image4.load(path + "/images/tux-large.png", NULL, DiffuseAlphaDither);

	Off = new QPixmap();
	On = new QPixmap();
	Warn = new QPixmap();

    if ( !name )
	setName( "Settings" );
	setMinimumSize( 493, 474 );
	setMaximumSize( 493, 474 );
    resize( 493, 473 ); 
    setCaption( tr( "Settings" ) );

	R = ptr;

    OKButton = new QPushButton( this, "OKButton" );
    OKButton->setGeometry( QRect( 120, 436, 70, 31 ) ); 
    OKButton->setText( tr( "OK" ) );
    QToolTip::add(  OKButton, tr( "OK button" ) );
	OKButton->setAccel( CTRL + Key_Return );
	OKButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  OKButton, tr( "Apply all changes and close the settings window." ) );
	connect (OKButton, SIGNAL ( clicked() ), this, SLOT ( OK() ) );

    SaveSettingsButton = new QPushButton( this, "SaveSettingsButton" );
    SaveSettingsButton->setGeometry( QRect( 6, 436, 90, 31 ) ); 
    SaveSettingsButton->setText( tr( "Save Settings" ) );
	SaveSettingsButton->setAccel( CTRL + Key_S );
	SaveSettingsButton->setFocusPolicy( QWidget::StrongFocus );
    QToolTip::add(  SaveSettingsButton, tr( "Save settings button" ) );
    QWhatsThis::add(  SaveSettingsButton, tr( "Save all settings in the user's home folder in the file named <.rtmix>." ) );
	connect (SaveSettingsButton, SIGNAL ( clicked() ), this, SLOT ( SaveSettings() ) );

    DefaultsButton = new QPushButton( this, "DefaultsButton" );
    DefaultsButton->setGeometry( QRect( 360, 436, 70, 31 ) ); 
    DefaultsButton->setText( tr( "Defaults" ) );
	DefaultsButton->setAccel( CTRL + Key_D );
	DefaultsButton->setFocusPolicy( QWidget::StrongFocus );
    QToolTip::add(  DefaultsButton, tr( "Reset all settings to defaults." ) );
    QWhatsThis::add(  DefaultsButton, tr( "Click here to reset all settings to application's defaults. Note: this button does not affect toggling of the external windows." ) );
	connect (DefaultsButton, SIGNAL ( clicked() ), this, SLOT ( ResetAll() ) );

    CancelButton = new QPushButton( this, "CancelButton" );
    CancelButton->setGeometry( QRect( 280, 436, 70, 31 ) ); 
    CancelButton->setText( tr( "Cancel" ) );
    CancelButton->setDefault( TRUE );
	CancelButton->setAccel( CTRL + Key_C );
	CancelButton->setFocusPolicy( QWidget::StrongFocus );
    QToolTip::add(  CancelButton, tr( "Cancel button" ) );
    QWhatsThis::add(  CancelButton, tr( "Cancel all changes and close the settings window." ) );
	connect (CancelButton, SIGNAL ( clicked() ), this, SLOT ( Close() ) );

    ApplyButton = new QPushButton( this, "ApplyButton" );
    ApplyButton->setGeometry( QRect( 200, 436, 70, 31 ) ); 
    ApplyButton->setText( tr( "Apply" ) );
	ApplyButton->setAccel( CTRL + Key_A );
	ApplyButton->setFocusPolicy( QWidget::StrongFocus );
    QToolTip::add(  ApplyButton, tr( "Apply button" ) );
    QWhatsThis::add(  ApplyButton, tr( "Apply all changes and leave the settings window open." ) );
	connect (ApplyButton, SIGNAL ( clicked() ), this, SLOT ( ApplyAllSettings() ) );

    WhatsThisButton = new QPushButton( this, "WhatsThisButton" );
    WhatsThisButton->setGeometry( QRect( 456, 436, 30, 31 ) ); 
    QFont WhatsThisButton_font(  WhatsThisButton->font() );
	WhatsThisButton->setAccel( Key_F1 );
    WhatsThisButton_font.setPointSize( 9 );
    WhatsThisButton->setFont( WhatsThisButton_font ); 
    WhatsThisButton->setText( tr( "?" ) );
	WhatsThisButton->setFocusPolicy( QWidget::StrongFocus );
    QToolTip::add(  WhatsThisButton, tr( "What's This button" ) );
    QWhatsThis::add(  WhatsThisButton, tr( "Click here and then click on the option in order to find out more about it." ) );
	connect (WhatsThisButton, SIGNAL ( clicked() ), this, SLOT ( HelpMode() ) );

    TabWidget = new QTabWidget( this, "TabWidget" );
    TabWidget->setGeometry( QRect( 6, 6, 480, 420 ) ); 
    TabWidget->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, TabWidget->sizePolicy().hasHeightForWidth() ) );
    QToolTip::add(  TabWidget, tr( "" ) );

    tab = new QWidget( TabWidget, "tab" );

    ToggleControlsGroup = new QGroupBox( tab, "ToggleControlsGroup" );
    ToggleControlsGroup->setGeometry( QRect( 10, 0, 460, 230 ) );
    ToggleControlsGroup->setTitle( tr( "Toggle Controls" ) );
    ToggleControlsGroup->setAlignment( int( QGroupBox::AlignHCenter ) );

    MetronomesGroup = new QButtonGroup( ToggleControlsGroup, "MetronomesGroup" );
    MetronomesGroup->setGeometry( QRect( 160, 20, 140, 130 ) );
    MetronomesGroup->setTitle( tr( "Metronomes" ) );
    MetronomesGroup->setAlignment( int( QButtonGroup::AlignHCenter ) );
    QWhatsThis::add(  MetronomesGroup, tr( "Toggle visibility of the Metronome windows." ) );
    MetronomesGroup->setColumnLayout(0, Qt::Vertical );
    MetronomesGroup->layout()->setSpacing( 0 );
    MetronomesGroup->layout()->setMargin( 0 );
    MetronomesGroupLayout = new QVBoxLayout( MetronomesGroup->layout() );
    MetronomesGroupLayout->setAlignment( Qt::AlignTop );
    MetronomesGroupLayout->setSpacing( 2 );
    MetronomesGroupLayout->setMargin( 11 );

    Metro1CheckBox = new QCheckBox( MetronomesGroup, "Metro1CheckBox" );
    Metro1CheckBox->setText( tr( "Metro 1" ) );
    MetronomesGroupLayout->addWidget( Metro1CheckBox );
 	connect (Metro1CheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleMetro1( int ) ) );

    Metro2CheckBox = new QCheckBox( MetronomesGroup, "Metro2CheckBox" );
    Metro2CheckBox->setText( tr( "Metro 2" ) );
    MetronomesGroupLayout->addWidget( Metro2CheckBox );
 	connect (Metro2CheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleMetro2( int ) ) );

    Metro3CheckBox = new QCheckBox( MetronomesGroup, "Metro3CheckBox" );
    Metro3CheckBox->setText( tr( "Metro 3" ) );
    MetronomesGroupLayout->addWidget( Metro3CheckBox );
 	connect (Metro3CheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleMetro3( int ) ) );

    Metro4CheckBox = new QCheckBox( MetronomesGroup, "Metro4CheckBox" );
    Metro4CheckBox->setText( tr( "Metro 4" ) );
    MetronomesGroupLayout->addWidget( Metro4CheckBox );
 	connect (Metro4CheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleMetro4( int ) ) );

    WarningWindowsGroup = new QButtonGroup( ToggleControlsGroup, "WarningWindowsGroup" );
    WarningWindowsGroup->setGeometry( QRect( 10, 20, 140, 130 ) );
    WarningWindowsGroup->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, WarningWindowsGroup->sizePolicy().hasHeightForWidth() ) );
    WarningWindowsGroup->setTitle( tr( "Warning Windows" ) );
    WarningWindowsGroup->setAlignment( int( QButtonGroup::AlignHCenter ) );
    QWhatsThis::add(  WarningWindowsGroup, tr( "Toggle visibility of the Warning windows." ) );
    WarningWindowsGroup->setColumnLayout(0, Qt::Vertical );
    WarningWindowsGroup->layout()->setSpacing( 0 );
    WarningWindowsGroup->layout()->setMargin( 0 );
    WarningWindowsGroupLayout = new QVBoxLayout( WarningWindowsGroup->layout() );
    WarningWindowsGroupLayout->setAlignment( Qt::AlignTop );
    WarningWindowsGroupLayout->setSpacing( 2 );
    WarningWindowsGroupLayout->setMargin( 11 );

    Window1CheckBox = new QCheckBox( WarningWindowsGroup, "Window1CheckBox" );
    Window1CheckBox->setText( tr( "Window 1" ) );
    WarningWindowsGroupLayout->addWidget( Window1CheckBox );
	connect (Window1CheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleWarning1( int ) ) );	

    Window2CheckBox = new QCheckBox( WarningWindowsGroup, "Window2CheckBox" );
    Window2CheckBox->setText( tr( "Window 2" ) );
    WarningWindowsGroupLayout->addWidget( Window2CheckBox );
	connect (Window2CheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleWarning2( int ) ) );	

    Window3CheckBox = new QCheckBox( WarningWindowsGroup, "Window3CheckBox" );
    Window3CheckBox->setText( tr( "Window 3" ) );
    WarningWindowsGroupLayout->addWidget( Window3CheckBox );
	connect (Window3CheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleWarning3( int ) ) );	

    Window4CheckBox = new QCheckBox( WarningWindowsGroup, "Window4CheckBox" );
    Window4CheckBox->setText( tr( "Window 4" ) );
    WarningWindowsGroupLayout->addWidget( Window4CheckBox );
	connect (Window4CheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleWarning4( int ) ) );	

    MainWindowSizeGroup = new QButtonGroup( ToggleControlsGroup, "MainWindowSizeGroup" );
    MainWindowSizeGroup->setGeometry( QRect( 10, 150, 140, 70 ) );
    MainWindowSizeGroup->setTitle( tr( "Main Window Size" ) );
    MainWindowSizeGroup->setAlignment( int( QButtonGroup::AlignHCenter ) );
    QWhatsThis::add(  MainWindowSizeGroup, tr( "Resize the main RTMix window. This can also be done by clicking the \"resize\" button on the top of the main RTMix window." ) );
    MainWindowSizeGroup->setColumnLayout(0, Qt::Vertical );
    MainWindowSizeGroup->layout()->setSpacing( 0 );
    MainWindowSizeGroup->layout()->setMargin( 0 );
    MainWindowSizeGroupLayout = new QVBoxLayout( MainWindowSizeGroup->layout() );
    MainWindowSizeGroupLayout->setAlignment( Qt::AlignTop );
    MainWindowSizeGroupLayout->setSpacing( 2 );
    MainWindowSizeGroupLayout->setMargin( 11 );

    FullSizeMainRadio = new QRadioButton( MainWindowSizeGroup, "FullSizeMainRadio" );
    FullSizeMainRadio->setText( tr( "Full Size" ) );
    FullSizeMainRadio->setChecked( TRUE );
    MainWindowSizeGroupLayout->addWidget( FullSizeMainRadio );

    CompactMainRadio = new QRadioButton( MainWindowSizeGroup, "CompactMainRadio" );
    CompactMainRadio->setText( tr( "Compact" ) );
    QWhatsThis::add(  CompactMainRadio, tr( "" ) );
    MainWindowSizeGroupLayout->addWidget( CompactMainRadio );


    OtherGroup = new QButtonGroup( ToggleControlsGroup, "OtherGroup" );
    OtherGroup->setGeometry( QRect( 310, 20, 140, 200 ) );
    OtherGroup->setTitle( tr( "Other" ) );
    OtherGroup->setAlignment( int( QButtonGroup::AlignHCenter ) );
    QWhatsThis::add(  OtherGroup, tr( "Toggle visibility of various independent widgets. Click with the 'what's this' pointer on each of the buttons to find out more." ) );
    OtherGroup->setColumnLayout(0, Qt::Vertical );
    OtherGroup->layout()->setSpacing( 0 );
    OtherGroup->layout()->setMargin( 0 );
    OtherGroupLayout = new QVBoxLayout( OtherGroup->layout() );
    OtherGroupLayout->setAlignment( Qt::AlignTop );
    OtherGroupLayout->setSpacing( 2 );
    OtherGroupLayout->setMargin( 11 );

    ExternAbsTimerCheckBox = new QCheckBox( OtherGroup, "ExternAbsTimerCheckBox" );
    ExternAbsTimerCheckBox->setText( tr( "Absolute Timer" ) );
    QWhatsThis::add(  ExternAbsTimerCheckBox, tr( "Toggle visibility of the external ABSOLUTE Timer widget. This timer reflects total performance duration and is not affected by jump, rew, and ffw events. Due to a possibility of having such jumps, this timer will potentially not be accurate if there are mid-rehearsal stops and adjustments to the main timer. However, in performance settings, as well as situations where there are no MANUAL adjustments made to the main timer, this timer will accurately reflect the amount of time elapsed since the beginning of the piece." ) );
    OtherGroupLayout->addWidget( ExternAbsTimerCheckBox );
	connect (ExternAbsTimerCheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleAbsTimer( int ) ) );

    ExternTimerCheckBox = new QCheckBox( OtherGroup, "ExternTimerCheckBox" );
    ExternTimerCheckBox->setText( tr( "External Timer" ) );
    QWhatsThis::add(  ExternTimerCheckBox, tr( "Toggle visibility of the external Timer widget (useful for Xinerama settings -- this timer is identical to the main timer on the main widget)." ) );
    OtherGroupLayout->addWidget( ExternTimerCheckBox );
	connect (ExternTimerCheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleTimer( int ) ) );

    LEDWindowCheckBox = new QCheckBox( OtherGroup, "LEDWindowCheckBox" );
    LEDWindowCheckBox->setText( tr( "LED Window" ) );
    QWhatsThis::add(  LEDWindowCheckBox, tr( "Toggle visibility of the LED Window." ) );
    OtherGroupLayout->addWidget( LEDWindowCheckBox );
	connect (LEDWindowCheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleLEDw( int ) ) );

/*  
    ExternalErrorLogCheckBox = new QCheckBox( OtherGroup, "ExternalErrorLogCheckBox" );
    ExternalErrorLogCheckBox->setText( tr( "Console" ) );
    QWhatsThis::add(  ExternalErrorLogCheckBox, tr( "Toggle visibility of the Console." ) );
    OtherGroupLayout->addWidget( ExternalErrorLogCheckBox );
	connect (ExternalErrorLogCheckBox, SIGNAL ( stateChanged( int ) ), this, SLOT ( ToggleExternErrorLog( int ) ) );
*/
  
    CloseAllButton = new QPushButton( ToggleControlsGroup, "CloseAllButton" );
    CloseAllButton->setGeometry( QRect( 195, 185, 70, 31 ) );
    CloseAllButton->setText( tr( "Close All" ) );
	CloseAllButton->setAccel( CTRL + Key_W );
	CloseAllButton->setFocusPolicy( QWidget::StrongFocus );
    QToolTip::add(  CloseAllButton, tr( "Close all external windows." ) );
    QWhatsThis::add(  CloseAllButton, tr( "Close all external windows with one click. Note: this does not affect the size of the main window." ) );
	connect (CloseAllButton, SIGNAL ( clicked() ), this, SLOT ( CloseAll() ) );

    ShortcutsGroup = new QGroupBox( tab, "ShortcutsGroup" );
    ShortcutsGroup->setGeometry( QRect( 10, 230, 460, 150 ) ); 
    ShortcutsGroup->setTitle( tr( "Keyboard Shortcuts" ) );
    ShortcutsGroup->setAlignment( int( QGroupBox::AlignHCenter ) );
    QWhatsThis::add(  LEDWindowCheckBox, tr( "Displays the current shortcut of the selected widget." ) );

    SelectWidgetLabel = new QLabel( ShortcutsGroup, "SelectWidgetLabel" );
    SelectWidgetLabel->setGeometry( QRect( 120, 19, 221, 21 ) ); 
    SelectWidgetLabel->setText( tr( "Select Widget to be controlled:" ) );
    SelectWidgetLabel->setAlignment( int( QLabel::AlignCenter ) );

    ShortcutComboBox = new QComboBox( FALSE, ShortcutsGroup, "ShortcutComboBox" );
    ShortcutComboBox->insertItem( tr( "Play Button" ) );
    ShortcutComboBox->insertItem( tr( "Pause Button" ) );
    ShortcutComboBox->insertItem( tr( "Rewind Button" ) );
    ShortcutComboBox->insertItem( tr( "Pause Button" ) );
    ShortcutComboBox->insertItem( tr( "Stop Button" ) );
    ShortcutComboBox->insertItem( tr( "Panic Button" ) );
    //ShortcutComboBox->insertItem( tr( "Toggle Size Button" ) );
    //ShortcutComboBox->insertItem( tr( "What's This? Button" ) );
    //ShortcutComboBox->insertItem( tr( "Settings Button" ) );
    //ShortcutComboBox->insertItem( tr( "Quit Button" ) );
    //ShortcutComboBox->insertItem( tr( "New File Button" ) );
    //ShortcutComboBox->insertItem( tr( "Open File Button" ) );
    //ShortcutComboBox->insertItem( tr( "Save File Button" ) );
    //ShortcutComboBox->insertItem( tr( "Save As Button" ) );
    //ShortcutComboBox->insertItem( tr( "Compile Button" ) );
    ShortcutComboBox->setGeometry( QRect( 10, 40, 440, 30 ) ); 
    QWhatsThis::add(  ShortcutComboBox, tr( "Select button to associate it with the new keyboard shortcut." ) );
	connect( ShortcutComboBox, SIGNAL ( activated( int ) ), this, SLOT ( AdjustShortcut( int ) ) );

    NewShortcutLineEdit = new QLineEdit( ShortcutsGroup, "NewShortcutLineEdit" );
    NewShortcutLineEdit->setGeometry( QRect( 170, 110, 150, 26 ) ); 
    QWhatsThis::add(  NewShortcutLineEdit, tr( "Enter here new shortcut. Please use key combinations, preferrably ALT+<KEY> or for example CTRL+S (for CTRL + 'S' combination) in order to minimize collision with regular script editing (where typing into the editor window may trigger comands if only a simple <KEY> is associated with a particular command). For complete syntax, please see the Docs." ) );
	connect( NewShortcutLineEdit, SIGNAL ( textChanged(const QString &) ), this, SLOT ( ApplyShortcut() ) );



/*
    ApplyShortcutButton = new QPushButton( ShortcutsGroup, "ApplyShortcutButton" );
    ApplyShortcutButton->setGeometry( QRect( 340, 79, 110, 25 ) ); 
    ApplyShortcutButton->setText( tr( "Apply" ) );
	ApplyShortcutButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  ApplyShortcutButton, tr( "Apply newly selected shortcut" ) );
	connect( ApplyShortcutButton, SIGNAL ( clicked() ), this, SLOT ( ApplyShortcut() ) );
*/
    DefaultShortcutButton = new QPushButton( ShortcutsGroup, "DefaultShortcutButton" );
    DefaultShortcutButton->setGeometry( QRect( 340, 107, 110, 31 ) );
    DefaultShortcutButton->setText( tr( "Reset to Default" ) );
	DefaultShortcutButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  DefaultShortcutButton, tr( "Reset shortcut to its default value." ) );
	connect( DefaultShortcutButton, SIGNAL ( clicked() ), this, SLOT ( DefaultShortcut() ) );

    CurrentShortcutFrame = new QFrame( ShortcutsGroup, "CurrentShortcutFrame" );
    CurrentShortcutFrame->setGeometry( QRect( 10, 81, 140, 60 ) ); 
    CurrentShortcutFrame->setFrameShape( QFrame::Box );
    CurrentShortcutFrame->setFrameShadow( QFrame::Sunken );

    CurrentShortcutLabel = new QLabel( CurrentShortcutFrame, "CurrentShortcutLabel" );
    CurrentShortcutLabel->setGeometry( QRect( 10, 5, 120, 20 ) ); 
    CurrentShortcutLabel->setText( tr( "Current Shortcut:" ) );
    CurrentShortcutLabel->setAlignment( int( QLabel::AlignCenter ) );

    CurrentShortcut = new QLabel( CurrentShortcutFrame, "CurrentShortcut" );
    CurrentShortcut->setGeometry( QRect( 11, 27, 120, 24 ) ); 
    CurrentShortcut->setFrameShape( QLabel::StyledPanel );
    CurrentShortcut->setFrameShadow( QLabel::Sunken );
    CurrentShortcut->setText( tr( "N/A" ) );
    CurrentShortcut->setAlignment( int( QLabel::AlignCenter ) );

    NewShortcutLabel = new QLabel( ShortcutsGroup, "NewShortcutLabel" );
    NewShortcutLabel->setGeometry( QRect( 170, 83, 150, 21 ) ); 
    NewShortcutLabel->setText( tr( "New keyboard shortcut:" ) );
    NewShortcutLabel->setAlignment( int( QLabel::AlignCenter ) );
    TabWidget->insertTab( tab, tr( "General" ) );

    tab_2 = new QWidget( TabWidget, "tab_2" );

    TimersGroup = new QGroupBox( tab_2, "TimersGroup" );
    TimersGroup->setGeometry( QRect( 10, 230, 460, 150 ) ); 
    TimersGroup->setTitle( tr( "Timers" ) );
    TimersGroup->setAlignment( int( QGroupBox::AlignHCenter ) );

    PreviewTimerLabel = new QLabel( TimersGroup, "PreviewTimerLabel" );
    PreviewTimerLabel->setGeometry( QRect( 342, 16, 111, 21 ) ); 
    PreviewTimerLabel->setText( tr( "Preview Pane" ) );
    PreviewTimerLabel->setAlignment( int( QLabel::AlignCenter ) );

    SelectTimerLabel = new QLabel( TimersGroup, "SelectTimerLabel" );
    SelectTimerLabel->setGeometry( QRect( 10, 19, 320, 21 ) ); 
    SelectTimerLabel->setText( tr( "Select Timer:" ) );
    SelectTimerLabel->setAlignment( int( QLabel::AlignCenter ) );

    PreviewLCD = new QLCD( TimersGroup, "PreviewLCD" );
    PreviewLCD->setGeometry( QRect( 350, 40, 90, 90 ) );
    cgLCD.setColor( QColorGroup::Foreground, QColor( 85, 255, 0) );
    cgLCD.setColor( QColorGroup::Button, QColor( 85, 255, 0) );
    cgLCD.setColor( QColorGroup::Light, QColor( 170, 255, 127) );
    cgLCD.setColor( QColorGroup::Midlight, QColor( 127, 255, 63) );
    cgLCD.setColor( QColorGroup::Dark, QColor( 42, 127, 0) );
    cgLCD.setColor( QColorGroup::Mid, QColor( 57, 170, 0) );
    cgLCD.setColor( QColorGroup::Text, QColor( 85, 255, 0) );
    cgLCD.setColor( QColorGroup::BrightText, white );
    cgLCD.setColor( QColorGroup::ButtonText, QColor( 85, 255, 0) );
    cgLCD.setColor( QColorGroup::Base, white );
    cgLCD.setColor( QColorGroup::Background, black );
    cgLCD.setColor( QColorGroup::Shadow, black );
    cgLCD.setColor( QColorGroup::Highlight, QColor( 80, 129, 153) );
    cgLCD.setColor( QColorGroup::HighlightedText, white );
    palLCD.setActive( cgLCD );
    palLCD.setInactive( cgLCD );
    palLCD.setDisabled( cgLCD );
    PreviewLCD->setPalette( palLCD );
    PreviewLCD->setCursor( QCursor( 5 ) );
    PreviewLCD->setAutoMask( FALSE );
    PreviewLCD->setFrameShape( QLCDNumber::StyledPanel );
    PreviewLCD->setFrameShadow( QLCDNumber::Sunken );
    PreviewLCD->setLineWidth( 0 );
    PreviewLCD->setMargin( 0 );
    PreviewLCD->setNumDigits( 2 );
    PreviewLCD->setSegmentStyle( QLCDNumber::Filled );
    PreviewLCD->setProperty( "intValue", 12 );
    QToolTip::add(  PreviewLCD, tr( "" ) );
    QWhatsThis::add(  PreviewLCD, tr( "Preview your Timer preferences here. Left-click to increase the value, or Right-click to decrease it." ) );
	connect (PreviewLCD, SIGNAL ( lclicked() ), this, SLOT ( IncreaseLCD() ) );
	connect (PreviewLCD, SIGNAL ( rclicked() ), this, SLOT ( DecreaseLCD() ) );

    SelectTimerColorBox = new QPushButton( TimersGroup, "SelectTimerColorBox" );
    SelectTimerColorBox->setGeometry( QRect( 10, 90, 80, 31 ) ); 
    SelectTimerColorBox->setText( tr( "Select Color" ) );
    QWhatsThis::add(  SelectTimerColorBox, tr( "Select new Timer's color." ) );
	connect( SelectTimerColorBox, SIGNAL ( clicked() ), this, SLOT ( UpdatePreviewColor() ) );

    TimerComboBox = new QComboBox( FALSE, TimersGroup, "TimerComboBox" );
    TimerComboBox->insertItem( tr( "Main Timer" ) );
    TimerComboBox->insertItem( tr( "Countdown Timer" ) );
    TimerComboBox->insertItem( tr( "Warning Window 1" ) );
    TimerComboBox->insertItem( tr( "Warning Window 2" ) );
    TimerComboBox->insertItem( tr( "Warning Window 3" ) );
    TimerComboBox->insertItem( tr( "Warning Window 4" ) );
    TimerComboBox->insertItem( tr( "Absolute Timer" ) );
    TimerComboBox->setGeometry( QRect( 10, 40, 320, 31 ) );
    QToolTip::add(  TimerComboBox, tr( "" ) );
    QWhatsThis::add(  TimerComboBox, tr( "Select Timer whose color you wish to alter." ) );
	connect( TimerComboBox, SIGNAL ( activated( int ) ), this, SLOT ( AdjustPreviewLCD( int ) ) );

    ResetTimerColorBox = new QPushButton( TimersGroup, "ResetTimerColorBox" );
    ResetTimerColorBox->setGeometry( QRect( 110, 90, 110, 31 ) );
    ResetTimerColorBox->setText( tr( "Reset to Default" ) );
    QWhatsThis::add(  ResetTimerColorBox, tr( "Reset to default Timer's color." ) );
	connect( ResetTimerColorBox, SIGNAL ( clicked() ), this, SLOT ( DefaultColor() ) );
/*
    ApplyTimerColorBox = new QPushButton( TimersGroup, "ApplyTimerColorBox" );
    ApplyTimerColorBox->setGeometry( QRect( 115, 90, 80, 31 ) ); 
    ApplyTimerColorBox->setText( tr( "Apply" ) );
    QWhatsThis::add(  ApplyTimerColorBox, tr( "Apply newly selected Timer's color." ) );
*/
    ImagesGroup = new QGroupBox( tab_2, "ImagesGroup" );
    ImagesGroup->setGeometry( QRect( 10, 0, 460, 230 ) ); 
    ImagesGroup->setTitle( tr( "Images" ) );
    ImagesGroup->setAlignment( int( QGroupBox::AlignHCenter ) );

    PreviewPixmapLabel = new QLabel( ImagesGroup, "PreviewPixmapLabel" );
    PreviewPixmapLabel->setGeometry( QRect( 340, 20, 111, 21 ) ); 
    PreviewPixmapLabel->setText( tr( "Preview Pane" ) );
    PreviewPixmapLabel->setAlignment( int( QLabel::AlignCenter ) );

    WARNLabel = new QLabel( ImagesGroup, "WARNLabel" );
    WARNLabel->setGeometry( QRect( 10, 187, 50, 30 ) );
    WARNLabel->setText( tr( "WARN:" ) );
    WARNLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    OFFLabel = new QLabel( ImagesGroup, "OFFLabel" );
    OFFLabel->setGeometry( QRect( 10, 90, 50, 30 ) ); 
    OFFLabel->setText( tr( "OFF:" ) );
    OFFLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    WARNPixmapLineEdit = new QLineEdit( ImagesGroup, "WARNPixmapLineEdit" );
    WARNPixmapLineEdit->setGeometry( QRect( 60, 189, 180, 26 ) );
	WARNPixmapLineEdit->setReadOnly( TRUE );
    QWhatsThis::add(  WARNPixmapLineEdit, tr( "Absolute path to the WARN state image (if applicable)." ) );
/*
    ApplyPixmapButton = new QPushButton( ImagesGroup, "ApplyPixmapButton" );
    ApplyPixmapButton->setGeometry( QRect( 340, 157, 110, 26 ) ); 
    ApplyPixmapButton->setText( tr( "Apply" ) );
	ApplyPixmapButton->setFocusPolicy( QWidget::StrongFocus );
    QToolTip::add(  ApplyPixmapButton, tr( "" ) );
    QWhatsThis::add(  ApplyPixmapButton, tr( "Apply changes made to selected visual indicator." ) );
*/
    BrowseWARNButton = new QPushButton( ImagesGroup, "BroseWARNButton" );
    BrowseWARNButton->setGeometry( QRect( 250, 187, 80, 31 ) );
    BrowseWARNButton->setText( tr( "Browse" ) );
	BrowseWARNButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  BrowseWARNButton, tr( "Browse for image to alter WARN state of the image (this is equivalent to the default YELLOW a.k.a. BLINKING state)." ) );
	connect( BrowseWARNButton, SIGNAL ( clicked() ), this, SLOT ( BrowsePixmapWarn() ) );

    BrowseONButton = new QPushButton( ImagesGroup, "BrowseONButton" );
    BrowseONButton->setGeometry( QRect( 250, 140, 80, 31 ) ); 
    BrowseONButton->setText( tr( "Browse" ) );
	BrowseONButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  BrowseONButton, tr( "Browse for image to alter ON state of the image (this is equivalent to the default GREEN a.k.a. EXECUTE state)." ) );
	connect( BrowseONButton, SIGNAL ( clicked() ), this, SLOT ( BrowsePixmapOn() ) );

    BrowseOFFButton = new QPushButton( ImagesGroup, "BrowseOFFButton" );
    BrowseOFFButton->setGeometry( QRect( 250, 90, 80, 31 ) ); 
    BrowseOFFButton->setText( tr( "Browse" ) );
	BrowseOFFButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  BrowseOFFButton, tr( "Browse for image to alter OFF state of the image (this is equivalent to the default OFF state)." ) );
	connect( BrowseOFFButton, SIGNAL ( clicked() ), this, SLOT ( BrowsePixmapOff() ) );

    OFFPixmapLineEdit = new QLineEdit( ImagesGroup, "OFFPixmapLineEdit" );
    OFFPixmapLineEdit->setGeometry( QRect( 60, 92, 180, 26 ) );
	OFFPixmapLineEdit->setReadOnly( TRUE );
    QWhatsThis::add(  OFFPixmapLineEdit, tr( "Absolute path to the OFF state image." ) );

    ONPixmapLineEdit = new QLineEdit( ImagesGroup, "ONPixmapLineEdit" );
    ONPixmapLineEdit->setGeometry( QRect( 60, 140, 180, 26 ) );
	ONPixmapLineEdit->setReadOnly( TRUE );
    QWhatsThis::add(  ONPixmapLineEdit, tr( "Absolute path to the ON state image." ) );

    ONLabel = new QLabel( ImagesGroup, "ONLabel" );
    ONLabel->setGeometry( QRect( 10, 138, 50, 30 ) );
    ONLabel->setText( tr( "ON:" ) );
    ONLabel->setAlignment( int( QLabel::AlignVCenter | QLabel::AlignLeft ) );

    PreviewPixmap = new QLED( ImagesGroup, "PreviewPixmap" );
    PreviewPixmap->setGeometry( QRect( 340, 40, 110, 110 ) );
    PreviewPixmap->setScaledContents( TRUE );
    PreviewPixmap->setCursor( QCursor( 13 ) );
    PreviewPixmap->setIndent( 0 );
    QToolTip::add(  PreviewPixmap, tr( "" ) );
    QWhatsThis::add(  PreviewPixmap, tr( "Preview here object's appearance. Please left-click on the image to change image's state." ) );
	connect( PreviewPixmap, SIGNAL ( lclicked() ), this, SLOT ( UpdatePixmap() ) );
	PixmapState = 0;

    PreviewPixmapName = new QLabel( ImagesGroup, "ONLabel" );
    PreviewPixmapName->setGeometry( QRect( 365, 151, 60, 20 ) );
    QFont PreviewPixmapName_font(  PreviewPixmapName->font() );
    PreviewPixmapName_font.setBold( TRUE );
    PreviewPixmapName->setFont( PreviewPixmapName_font );
    PreviewPixmapName->setFrameShape( QLabel::StyledPanel );
    PreviewPixmapName->setFrameShadow( QLabel::Sunken );
    PreviewPixmapName->setText( tr( "OFF" ) );
    PreviewPixmapName->setAlignment( int( QLabel::AlignHCenter ) );

    DefaultPixmapButton = new QPushButton( ImagesGroup, "DefaultPixmapButton" );
    DefaultPixmapButton->setGeometry( QRect( 340, 187, 110, 31 ) );
    DefaultPixmapButton->setText( tr( "Reset to Default" ) );
	DefaultPixmapButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  DefaultPixmapButton, tr( "Reset selected visual indicator's appearance." ) );
	connect( DefaultPixmapButton, SIGNAL ( clicked() ), this, SLOT ( ResetPixmap() ) );

    PixmapComboBox = new QComboBox( FALSE, ImagesGroup, "PixmapComboBox" );
    PixmapComboBox->insertItem( tr( "Main Play Indicator" ) );
    PixmapComboBox->insertItem( tr( "Main Warn Indicator" ) );
    PixmapComboBox->insertItem( tr( "Main Execute Indicator" ) );
    PixmapComboBox->insertItem( tr( "Warning Window 1" ) );
    PixmapComboBox->insertItem( tr( "Warning Window 2" ) );
    PixmapComboBox->insertItem( tr( "Warning Window 3" ) );
    PixmapComboBox->insertItem( tr( "Warning Window 4" ) );
    PixmapComboBox->insertItem( tr( "Metronome 1" ) );
    PixmapComboBox->insertItem( tr( "Metronome 2" ) );
    PixmapComboBox->insertItem( tr( "Metronome 3" ) );
    PixmapComboBox->insertItem( tr( "Metronome 4" ) );
    PixmapComboBox->insertItem( tr( "LED Window Light 1" ) );
    PixmapComboBox->insertItem( tr( "LED Window Light 2" ) );
    PixmapComboBox->insertItem( tr( "LED Window Light 3" ) );
    PixmapComboBox->insertItem( tr( "LED Window Light 4" ) );
    PixmapComboBox->insertItem( tr( "LED Window Light 5" ) );
    PixmapComboBox->insertItem( tr( "LED Window Light 6" ) );
    PixmapComboBox->setGeometry( QRect( 10, 40, 320, 31 ) ); 
    QToolTip::add(  PixmapComboBox, tr( "" ) );
    QWhatsThis::add(  PixmapComboBox, tr( "Select visual indicator whose appearance you wish to alter." ) );
	connect( PixmapComboBox, SIGNAL ( activated( int ) ), this, SLOT ( AdjustPixmap( int ) ) );

    SelectPixmapLabel = new QLabel( ImagesGroup, "SelectPixmapLabel" );
    SelectPixmapLabel->setGeometry( QRect( 10, 19, 320, 21 ) ); 
    SelectPixmapLabel->setText( tr( "Select Object:" ) );
    SelectPixmapLabel->setAlignment( int( QLabel::AlignCenter ) );
    TabWidget->insertTab( tab_2, tr( "Visuals" ) );

    Fonts = new QWidget( TabWidget, "Fonts" );

    VerticalArrow = new QLabel( Fonts, "VerticalArrow" );
    VerticalArrow->setGeometry( QRect( 310, 200, 40, 60 ) ); 
    VerticalArrow->setPixmap( image1 );
    VerticalArrow->setScaledContents( TRUE );

    HorizontalArrow = new QLabel( Fonts, "HorizontalArrow" );
    HorizontalArrow->setGeometry( QRect( 199, 97, 60, 40 ) ); 
    HorizontalArrow->setPixmap( image2 );
    HorizontalArrow->setScaledContents( TRUE );

    FontButtonsFrame = new QFrame( Fonts, "FontButtonsFrame" );
    FontButtonsFrame->setGeometry( QRect( 260, 30, 140, 170 ) ); 
    FontButtonsFrame->setFrameShape( QFrame::Box );
    FontButtonsFrame->setFrameShadow( QFrame::Sunken );
    QToolTip::add(  FontButtonsFrame, tr( "" ) );
    QWhatsThis::add(  FontButtonsFrame, tr( "Select action to perform on the font group." ) );

/*
    ApplyFontButton = new QPushButton( FontButtonsFrame, "ApplyFontButton" );
    ApplyFontButton->setGeometry( QRect( 30, 90, 80, 31 ) ); 
    ApplyFontButton->setText( tr( "Apply" ) );
	ApplyFontButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  ApplyFontButton, tr( "Apply changes to select fonts." ) );
*/
    SelectFontButton = new QPushButton( FontButtonsFrame, "SelectFontButton" );
    SelectFontButton->setGeometry( QRect( 30, 10, 80, 36 ) );
    SelectFontButton->setText( tr( "Select Font" ) );
	SelectFontButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  SelectFontButton, tr( "Select new font for the font group in question." ) );
	connect( SelectFontButton, SIGNAL ( clicked() ), this, SLOT ( SelectFont() ) );

    SelectColorButton = new QPushButton( FontButtonsFrame, "SelectColorButton" );
    SelectColorButton->setGeometry( QRect( 30, 60, 80, 36 ) );
    SelectColorButton->setText( tr( "Select Color" ) );
	SelectColorButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  SelectColorButton, tr( "Select new font color for the font group in question." ) );
	connect( SelectColorButton, SIGNAL ( clicked() ), this, SLOT ( SelectFontColor() ) );

    DefaultFontButton = new QPushButton( FontButtonsFrame, "DefaultFontButton" );
    DefaultFontButton->setGeometry( QRect( 10, 125, 120, 36 ) );
    DefaultFontButton->setText( tr( "Reset to Default" ) );
	DefaultFontButton->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  DefaultFontButton, tr( "Reset select fonts to their defaults." ) );
	connect( DefaultFontButton, SIGNAL ( clicked() ), this, SLOT ( DefaultFont() ) );

    FontAppearanceGroup = new QGroupBox( Fonts, "FontAppearanceGroup" );
    FontAppearanceGroup->setGeometry( QRect( 10, 260, 460, 120 ) ); 
    FontAppearanceGroup->setTitle( tr( "Appearance of the Currently Selected" ) );
    FontAppearanceGroup->setAlignment( int( QGroupBox::AlignHCenter ) );

    FontDemoMultiLineEdit = new QTextEdit( FontAppearanceGroup, "FontDemoMultiLineEdit" );
    FontDemoMultiLineEdit->setGeometry( QRect( 10, 20, 440, 90 ) ); 
    cgEdit.setColor( QColorGroup::Foreground, black );
    cgEdit.setColor( QColorGroup::Button, QColor( 228, 228, 228) );
    cgEdit.setColor( QColorGroup::Light, white );
    cgEdit.setColor( QColorGroup::Midlight, QColor( 241, 241, 241) );
    cgEdit.setColor( QColorGroup::Dark, QColor( 114, 114, 114) );
    cgEdit.setColor( QColorGroup::Mid, QColor( 152, 152, 152) );
    cgEdit.setColor( QColorGroup::Text, black );
    cgEdit.setColor( QColorGroup::BrightText, white );
    cgEdit.setColor( QColorGroup::ButtonText, black );
    cgEdit.setColor( QColorGroup::Base, backgroundColor() );
    cgEdit.setColor( QColorGroup::Background, backgroundColor() );
    cgEdit.setColor( QColorGroup::Shadow, black );
    cgEdit.setColor( QColorGroup::Highlight, QColor( 80, 129, 153) );
    cgEdit.setColor( QColorGroup::HighlightedText, white );
    palEdit.setActive( cgEdit );
    palEdit.setInactive( cgEdit );
    palEdit.setDisabled( cgEdit );
    FontDemoMultiLineEdit->setPalette( palEdit );
    QFont FontDemoMultiLineEdit_font(  FontDemoMultiLineEdit->font() );
    FontDemoMultiLineEdit->setFont( FontDemoMultiLineEdit_font );
    FontDemoMultiLineEdit->setFocusPolicy( QWidget::ClickFocus );
    FontDemoMultiLineEdit->setText( tr( "This is the pane for testing of the fonts and font colors..." ) );
    QToolTip::add(  FontDemoMultiLineEdit, tr( "" ) );
    QWhatsThis::add(  FontDemoMultiLineEdit, tr( "Edit box for testing newly selected font" ) );
    cgEditDefault = cgEdit;
    palEditDefault = palEdit;

    FontGroup = new QButtonGroup( Fonts, "FontGroup" );
    FontGroup->setGeometry( QRect( 10, 3, 182, 248 ) );
    FontGroup->setTitle( tr( "Select Font Group" ) );
    FontGroup->setAlignment( int( QButtonGroup::AlignHCenter ) );
    QToolTip::add(  FontGroup, tr( "" ) );
    QWhatsThis::add(  FontGroup, tr( "Click on the font group you wish to edit." ) );
    FontGroup->setColumnLayout(0, Qt::Vertical );
    FontGroup->layout()->setSpacing( 0 );
    FontGroup->layout()->setMargin( 0 );
    FontGroupLayout = new QVBoxLayout( FontGroup->layout() );
    FontGroupLayout->setAlignment( Qt::AlignTop );
    FontGroupLayout->setSpacing( 6 );
    FontGroupLayout->setMargin( 11 );
	connect( FontGroup, SIGNAL ( clicked( int ) ), this, SLOT ( AdjustFont( int ) ) );

    GeneralFontRadio = new QRadioButton( FontGroup, "GeneralFontRadio" );
    GeneralFontRadio->setText( tr( "General Interface" ) );
    GeneralFontRadio->setChecked( TRUE );
    FontGroupLayout->addWidget( GeneralFontRadio );

    NotificationFontRadio = new QRadioButton( FontGroup, "NotificationFontRadio" );
    NotificationFontRadio->setText( tr( "Notification Interface" ) );
    FontGroupLayout->addWidget( NotificationFontRadio );

    EditorFontRadio = new QRadioButton( FontGroup, "EditorFontRadio" );
    EditorFontRadio->setText( tr( "Editor" ) );
    FontGroupLayout->addWidget( EditorFontRadio );

    /*
    InternalErrorFontRadio = new QRadioButton( FontGroup, "InternalErrorFontRadio" );
    InternalErrorFontRadio->setText( tr( "Internal Error Log" ) );
    FontGroupLayout->addWidget( InternalErrorFontRadio );
    */
    
    ExternalErrorFontRadio = new QRadioButton( FontGroup, "ExternalErrorFontRadio" );
    ExternalErrorFontRadio->setText( tr( "Console" ) );
    FontGroupLayout->addWidget( ExternalErrorFontRadio );

    WarningWindowFontRadio = new QRadioButton( FontGroup, "WarningWindowFontRadio" );
    WarningWindowFontRadio->setText( tr( "Warning Labels" ) );
    FontGroupLayout->addWidget( WarningWindowFontRadio );

    LEDWindowFontRadio = new QRadioButton( FontGroup, "LEDWindowFontRadio" );
    LEDWindowFontRadio->setText( tr( "LED Labels" ) );
    FontGroupLayout->addWidget( LEDWindowFontRadio );

    MetroFontRadio = new QRadioButton( FontGroup, "MetroFontRadio" );
   	MetroFontRadio->setText( tr( "Metronome Labels" ) );
    FontGroupLayout->addWidget( MetroFontRadio );
    TabWidget->insertTab( Fonts, tr( "Fonts" ) );

    About = new QWidget( TabWidget, "About" );

    WidgetNamesGroup = new QGroupBox( About, "WidgetNamesGroup" );
    WidgetNamesGroup->setGeometry( QRect( 10, 0, 460, 265 ) ); 
    WidgetNamesGroup->setTitle( tr( "Widget Names" ) );
    WidgetNamesGroup->setAlignment( int( QGroupBox::AlignHCenter ) );

    TextComboBox = new QComboBox( FALSE, WidgetNamesGroup, "TextComboBox" );
    TextComboBox->insertItem( tr( "Warning Window 1" ) );
    TextComboBox->insertItem( tr( "Warning Window 2" ) );
    TextComboBox->insertItem( tr( "Warning Window 3" ) );
    TextComboBox->insertItem( tr( "Warning Window 4" ) );
    TextComboBox->insertItem( tr( "Metronome 1" ) );
    TextComboBox->insertItem( tr( "Metronome 2" ) );
    TextComboBox->insertItem( tr( "Metronome 3" ) );
    TextComboBox->insertItem( tr( "Metronome 4" ) );
    TextComboBox->insertItem( tr( "LED Window Light 1" ) );
    TextComboBox->insertItem( tr( "LED Window Light 2" ) );
    TextComboBox->insertItem( tr( "LED Window Light 3" ) );
    TextComboBox->insertItem( tr( "LED Window Light 4" ) );
    TextComboBox->insertItem( tr( "LED Window Light 5" ) );
    TextComboBox->insertItem( tr( "LED Window Light 6" ) );
    TextComboBox->setGeometry( QRect( 70, 40, 320, 31 ) ); 
    QToolTip::add(  TextComboBox, tr( "" ) );
    QWhatsThis::add(  TextComboBox, tr( "Select name label whose title you wish to alter." ) );
	connect ( TextComboBox, SIGNAL ( activated( int ) ), this, SLOT ( AdjustName( int ) ) );

    SelectTextLabel = new QLabel( WidgetNamesGroup, "SelectTextLabel" );
    SelectTextLabel->setGeometry( QRect( 70, 19, 320, 20 ) ); 
    SelectTextLabel->setText( tr( "Select widget with customizable name:" ) );
    SelectTextLabel->setAlignment( int( QLabel::AlignCenter ) );

    CurrentTextFrame = new QFrame( WidgetNamesGroup, "CurrentTextFrame" );
    CurrentTextFrame->setGeometry( QRect( 110, 83, 230, 75 ) ); 
    CurrentTextFrame->setFrameShape( QFrame::Box );
    CurrentTextFrame->setFrameShadow( QFrame::Sunken );
    QWhatsThis::add(  CurrentTextFrame, tr( "Current name of the selected widget." ) );

    CurrentNameLabel = new QLabel( CurrentTextFrame, "CurrentNameLabel" );
    CurrentNameLabel->setGeometry( QRect( 30, 10, 170, 20 ) ); 
    CurrentNameLabel->setText( tr( "Current Name:" ) );
    CurrentNameLabel->setAlignment( int( QLabel::AlignCenter ) );

    CurrentName = new QLabel( CurrentTextFrame, "CurrentName" );
    CurrentName->setGeometry( QRect( 10, 40, 211, 25 ) ); 
    CurrentName->setFrameShape( QLabel::StyledPanel );
    CurrentName->setFrameShadow( QLabel::Sunken );
    CurrentName->setText( tr( "N/A" ) );
    CurrentName->setAlignment( int( QLabel::AlignCenter ) );

    NewNameLabel = new QLabel( WidgetNamesGroup, "NewNameLabel" );
    NewNameLabel->setGeometry( QRect( 70, 165, 320, 20 ) );
    NewNameLabel->setText( tr( "Enter new name:" ) );
    NewNameLabel->setAlignment( int( QLabel::AlignCenter ) );    
    
    NewNameLineEdit = new QLineEdit( WidgetNamesGroup, "NewNameLineEdit" );
    NewNameLineEdit->setGeometry( QRect( 70, 185, 320, 25 ) );
    QWhatsThis::add(  NewNameLineEdit, tr( "Enter new name of the widget." ) );
    connect( NewNameLineEdit, SIGNAL ( textChanged( const QString & ) ), this, SLOT ( ApplyName() ) );

    ResetTimerColorBox_2 = new QPushButton( WidgetNamesGroup, "ResetName" );
    ResetTimerColorBox_2->setGeometry( QRect( 170, 220, 110, 31 ) );
    ResetTimerColorBox_2->setText( tr( "Reset to Default" ) );
    ResetTimerColorBox_2->setFocusPolicy( QWidget::StrongFocus );
    QWhatsThis::add(  ResetTimerColorBox_2, tr( "Reset to default widget's name." ) );
    connect ( ResetTimerColorBox_2, SIGNAL ( clicked() ), this, SLOT ( DefaultName() ) );

    ExternalsGroup = new QGroupBox( About, "ExternalsGroup" );
    ExternalsGroup->setGeometry( QRect( 10, 265, 460, 115 ) );
    ExternalsGroup->setTitle( tr( "Paths" ) );
    ExternalsGroup->setAlignment( int( QGroupBox::AlignHCenter ) );
    QWhatsThis::add(  ExternalsGroup, tr( "Enter the full path and the executable of the program of your preference to use for external editing of script-files." ) );

    ExternalEditorLabel = new QLabel( ExternalsGroup, "ExternalEditorLabel" );
    ExternalEditorLabel->setGeometry( QRect( 10, 28, 90, 20 ) );
    ExternalEditorLabel->setText( tr( "External Editor:" ) );
    ExternalEditorLabel->setAlignment( int( QLabel::AlignLeft ) );

    ExternalEditorLineEdit = new QLineEdit( ExternalsGroup, "ExternalEditorLineEdit" );
    ExternalEditorLineEdit->setGeometry( QRect( 120, 23, 330, 25 ) );
    ExternalEditorLineEdit->setText( tr( "/usr/bin/kwrite" ) );
    connect( ExternalEditorLineEdit, SIGNAL ( textChanged( const QString & ) ), this, SLOT ( UpdateExternalEditor( const QString & ) ) );

    MidiPortEditLabel = new QLabel( ExternalsGroup, "MidiPortEditLabel" );
    MidiPortEditLabel->setGeometry( QRect( 10, 77, 70, 20 ) );
    MidiPortEditLabel->setText( tr( "Midi Port:" ) );
    MidiPortEditLabel->setAlignment( int( QLabel::AlignLeft ) );
    
    MidiPortEdit = new QLineEdit( ExternalsGroup, "MidiPort" );
    MidiPortEdit->setGeometry( QRect( 80, 73, 150, 25 ) );
    MidiPortEdit->setText( tr( "/dev/midi" ) );
    connect( MidiPortEdit, SIGNAL ( textChanged( const QString & ) ), this, SLOT ( ApplyMidiPort() ) );

    SpawnMidiButton = new QPushButton( ExternalsGroup, "SpawnMidiButton" );
    SpawnMidiButton->setGeometry( QRect( 240, 70, 70, 31 ) );
    SpawnMidiButton->setText( tr( "Connect" ) );
    SpawnMidiButton->setFocusPolicy( QWidget::StrongFocus );
    connect( SpawnMidiButton, SIGNAL ( clicked() ), this, SLOT ( ConnectMidi() ) );

    MidiStatus = new QLabel( ExternalsGroup, "MidiStatus" );
    MidiStatus->setGeometry( QRect( 320, 70, 130, 30 ) );
    MidiStatus->setFrameShape( QLabel::StyledPanel );
    MidiStatus->setFrameShadow( QLabel::Sunken );
    MidiStatus->setText( tr( "Status: OK" ) );
    MidiStatus->setAlignment( int( QLabel::AlignCenter ) );
    QToolTip::add(  MidiStatus, tr( "Current connection status with the MIDI port." ) );
    QWhatsThis::add(  MidiStatus, tr( "Current connection status with the MIDI port." ) );
            
    TabWidget->insertTab( About, tr( "Names/Paths" ) );
/*
    Help = new QWidget( TabWidget, "Help" );

    DocumentationGroup = new QGroupBox( Help, "DocumentationGroup" );
    DocumentationGroup->setGeometry( QRect( 10, 0, 460, 130 ) );
    DocumentationGroup->setTitle( tr( "Documentation" ) );
    DocumentationGroup->setAlignment( int( QGroupBox::AlignHCenter ) );

    Help1Label = new QLabel( DocumentationGroup, "Help1Label" );
    Help1Label->setGeometry( QRect( 70, 20, 320, 20 ) );
    Help1Label->setText( tr( "Help is available in two forms:" ) );
    Help1Label->setTextFormat( QLabel::AutoText );
    Help1Label->setAlignment( int( QLabel::WordBreak | QLabel::AlignCenter ) );

    Help2Label = new QLabel( DocumentationGroup, "Help2Label" );
    Help2Label->setGeometry( QRect( 11, 50, 440, 70 ) );
    Help2Label->setText( tr( "1) manual.doc file located in the /usr/local/rtmix/doc/ folder\n"
"\n"
"2) as HTML documentation located in the /usr/local/rtmix/doc/html/ folder" ) );
    Help2Label->setAlignment( int( QLabel::WordBreak | QLabel::AlignCenter ) );

    HelpOption2Group = new QGroupBox( Help, "HelpOption2Group" );
    HelpOption2Group->setGeometry( QRect( 11, 230, 460, 150 ) );
    HelpOption2Group->setTitle( tr( "View option 2" ) );
    HelpOption2Group->setAlignment( int( QGroupBox::AlignHCenter ) );

    Option2Label1 = new QLabel( HelpOption2Group, "Option2Label1" );
    Option2Label1->setGeometry( QRect( 80, 20, 300, 20 ) );
    Option2Label1->setText( tr( "Enter full path to your default browser's binary:" ) );
    Option2Label1->setAlignment( int( QLabel::AlignCenter ) );

    HTMLDocsButton = new QPushButton( HelpOption2Group, "HTMLDocsButton" );
    HTMLDocsButton->setGeometry( QRect( 150, 110, 161, 30 ) );
	HTMLDocsButton->setFocusPolicy( QWidget::StrongFocus );
    HTMLDocsButton->setText( tr( "View HTML Docs" ) );
	connect( HTMLDocsButton, SIGNAL ( clicked() ), this, SLOT ( OpenHTMLDoc() ) );

    Option2Label2 = new QLabel( HelpOption2Group, "Option2Label2" );
    Option2Label2->setGeometry( QRect( 10, 82, 440, 21 ) );
    Option2Label2->setText( tr( "Click here to access the HTML docs using the above HTML browser:" ) );
    Option2Label2->setAlignment( int( QLabel::AlignCenter ) );

    HelpOption1Group = new QGroupBox( Help, "HelpOption1Group" );
    HelpOption1Group->setGeometry( QRect( 10, 130, 461, 101 ) );
    HelpOption1Group->setTitle( tr( "View option 1" ) );
    HelpOption1Group->setAlignment( int( QGroupBox::AlignHCenter ) );

    Option1Label = new QLabel( HelpOption1Group, "Option1Label" );
    Option1Label->setGeometry( QRect( 30, 20, 401, 30 ) );
    Option1Label->setText( tr( "Click here to access the manual.doc file using the external text editor (configurable under the 'Names' tab):" ) );
    Option1Label->setAlignment( int( QLabel::WordBreak | QLabel::AlignCenter ) );
*/
    Net = new QWidget( TabWidget, "Net" );
    NetFrameGroup = new QGroupBox( Net, "Network Settings" );
    NetFrameGroup->setGeometry( QRect( 10, 0, 460, 380 ) );
    NetFrameGroup->setTitle( tr( "Network Settings" ) );
    //NetFrameGroup->setAlignment( int( QGroupBox::AlignHCenter ) );
    NetLabel = new QLabel( NetFrameGroup, "EditNetAuthLabel" );
    NetLabel->setGeometry( QRect( 70, 20, 320, 20 ) );
    NetLabel->setText( tr( "Edit Network Authentication Password:" ) );
    NetLabel->setAlignment( int( QLabel::AlignCenter ) );
    NetAuthEdit = new QLineEdit( NetFrameGroup, "NetEdit" );
    NetAuthEdit->setGeometry( QRect( 10, 50, 440, 25 ) );
    NetAuthEdit->setFocusPolicy( QWidget::ClickFocus );
    connect( NetAuthEdit, SIGNAL ( textChanged(const QString &) ), this, SLOT ( ApplyNetAuth(const QString &) ) );
    QToolTip::add(  NetAuthEdit, tr( "Network Connection Validator" ) );
    QWhatsThis::add(  NetAuthEdit, tr( "Edit or create a network connection authorization password \
used to ensure secure remote connections. You can use spaces, but not more than one space \
between the letters and/or words." ) );
    FilterLabel = new QLabel( NetFrameGroup, "EditFilterLabel" );
    FilterLabel->setGeometry( QRect( 70, 100, 320, 20 ) );
    FilterLabel->setText( tr( "Enter system-call events to be ignored:" ) );
    FilterLabel->setAlignment( int( QLabel::AlignCenter ) );
    Filter = new QTextEdit( NetFrameGroup, "EventFilter" );
    Filter->setGeometry( QRect( 10, 130, 440, 240 ) );
    Filter->setFocusPolicy( QWidget::ClickFocus );
    Filter->setWordWrap( QTextEdit::WidgetWidth );
    Filter->setText( tr( "" ) );
    QToolTip::add(  Filter, tr( "List of filtered system calls" ) );
    QWhatsThis::add(  Filter, tr( "Edit list of system events that are to be ignored for security reasons \
(affects both remote and local-invoked events). Make sure to separate each of the events with the \
comma (,) separator, and also keep track of the spaces since they help more accurately filter the events.\
Finally, filters are case-sensitive! NOTE: end-lines will be treated as spaces." ) );
    connect( Filter, SIGNAL ( textChanged() ), this, SLOT ( ApplyFilter() ) );    
    TabWidget->insertTab( Net, tr( "Network" ) );






    tab = new QWidget( TabWidget, "Help" );

    DocumentationGroup = new QGroupBox( tab, "DocumentationGroup" );
    DocumentationGroup->setGeometry( QRect( 10, 0, 460, 380 ) );
    DocumentationGroup->setTitle( tr( "Documentation" ) );
    DocumentationGroup->setAlignment( int( QGroupBox::AlignHCenter ) );

    BrowserLineEdit = new QLineEdit( DocumentationGroup, "BrowserLineEdit" );
    BrowserLineEdit->setGeometry( QRect( 90, 130, 280, 26 ) );
    BrowserLineEdit->setText( tr( "/usr/bin/mozilla" ) );
    connect( BrowserLineEdit, SIGNAL ( textChanged(const QString &) ), this, SLOT ( ApplyBrowser() ) );

    SelectBrowserLabel = new QLabel( DocumentationGroup, "SelectBrowserLabel" );
    SelectBrowserLabel->setGeometry( QRect( 100, 100, 260, 20 ) );
    SelectBrowserLabel->setText( tr( "Select your preferred HTML browser:" ) );
    SelectBrowserLabel->setAlignment( int( QLabel::AlignCenter ) );

    HelpLabel = new QLabel( DocumentationGroup, "HelpLabel" );
    HelpLabel->setGeometry( QRect( 57, 27, 350, 50 ) );
    HelpLabel->setText( tr( "RTMix documentation is available in HTML format only. It is located in the /usr/local/rtmix/doc/ folder." ) );
    HelpLabel->setScaledContents( TRUE );
    HelpLabel->setAlignment( int( QLabel::WordBreak | QLabel::AlignCenter ) );
    HelpLabel->setIndent( 0 );

    ViewHelpButton = new QPushButton( DocumentationGroup, "ViewHelpButton" );
    ViewHelpButton->setGeometry( QRect( 150, 170, 160, 31 ) );
    ViewHelpButton->setText( tr( "View Documentation" ) );
    QToolTip::add(  ViewHelpButton, tr( "View Documentation" ) );
    QWhatsThis::add(  ViewHelpButton, tr( "View documentation by spawning the default HTML browser specified \
above and opening the main documentation page in the /usr/local/rtmix/doc/ folder." ) );
    connect( ViewHelpButton, SIGNAL ( clicked() ), this, SLOT ( SpawnHelp() ) );
    
    TabWidget->insertTab( tab, tr( "Help" ) );












    
    
    tab_3 = new QWidget( TabWidget, "tab_3" );

    IcoLogo = new QLabel( tab_3, "IcoLogo" );
    IcoLogo->setGeometry( QRect( 180, 280, 290, 100 ) ); 
    IcoLogo->setFrameShape( QLabel::StyledPanel );
    IcoLogo->setFrameShadow( QLabel::Sunken );
    IcoLogo->setLineWidth( 1 );
    IcoLogo->setMargin( 0 );
    IcoLogo->setMidLineWidth( 0 );
    IcoLogo->setPixmap( image3 );
    IcoLogo->setScaledContents( TRUE );
    IcoLogo->setIndent( 0 );
    QToolTip::add(  IcoLogo, tr( "Ico's Logo" ) );

    DesignedWithLabel = new QLabel( tab_3, "DesignedWithLabel" );
    DesignedWithLabel->setGeometry( QRect( 12, 296, 121, 21 ) ); 
    DesignedWithLabel->setText( tr( "Designed with:" ) );
    DesignedWithLabel->setAlignment( int( QLabel::AlignCenter ) );

    QtLogo = new QLabel( tab_3, "QtLogo" );
    QtLogo->setGeometry( QRect( 70, 321, 60, 60 ) ); 
    QtLogo->setPixmap( image0 );
    QtLogo->setScaledContents( TRUE );
    QToolTip::add(  QtLogo, tr( "Qt Logo" ) );

    AuthorLabel = new QLabel( tab_3, "AuthorLabel" );
    AuthorLabel->setGeometry( QRect( 23, 36, 420, 110 ) ); 
    AuthorLabel->setText( tr( "A Real-Time Interactive Multimedia Interface\nv." + Version +"\n\n"
"Copyright Ivica Ico Bukvic 2001\n"
"ico@fuse.net\n"
"http://meowing.ccm.uc.edu/~ico/" ) );
    AuthorLabel->setAlignment( int( QLabel::AlignTop | QLabel::AlignHCenter ) );

    LicenseMultiLineEdit = new QTextEdit( tab_3, "LicenseMultiLineEdit" );
    LicenseMultiLineEdit->setEnabled( TRUE );
    LicenseMultiLineEdit->setGeometry( QRect( 10, 150, 460, 120 ) ); 
    LicenseMultiLineEdit->setAcceptDrops( FALSE );
    LicenseMultiLineEdit->setAlignment( int( Qt::AlignHCenter ) );
    LicenseMultiLineEdit->setMargin( 3 );
    LicenseMultiLineEdit->setWordWrap( QTextEdit::WidgetWidth );
    LicenseMultiLineEdit->setWrapColumnOrWidth( 0 );
    LicenseMultiLineEdit->setWrapPolicy( QTextEdit::AtWhiteSpace );
    LicenseMultiLineEdit->setUndoRedoEnabled( FALSE );
    LicenseMultiLineEdit->setUndoDepth( 0 );
    LicenseMultiLineEdit->setReadOnly( TRUE );
    LicenseMultiLineEdit->setText( tr( "This application is under GPL license (for more info please visit http://www.gnu.org/copyleft/gpl.html) or see documentation.\n"
"\n"
"This project was in part sponsored by the University Research Council grant of the University of Cincinnati.\n"
"\n"
"I would like to acknowledge the people without whom this application would not be possible: my wife Anamaria for her kind and loving support and patience, my son Sebastian -- my greatest inspiration, as well as my brother and my parents for always being there for me. Many thanks also to my mentor prof. Mara Helmuth as well as the University Research Council of the University of Cincinnati.\n"
"\n"
"This project has been first publicly presented on the ICMC 2002 conference in Gotteborg, Sweden.\n"
"Cincinnati, August 2002.\n"
"\n"
"Qt and Tux are trademarks of their respective owners Trolltech (www.trolltech.com) and Linus Torvalds." ) );
    QToolTip::add(  LicenseMultiLineEdit, tr( "License Window" ) );

    RTMixLabel = new QLabel( tab_3, "RTMixLabel" );
    RTMixLabel->setGeometry( QRect( 160, 10, 150, 20 ) ); 
    QFont RTMixLabel_font(  RTMixLabel->font() );
    RTMixLabel_font.setPointSize( 12 );
    RTMixLabel_font.setBold( TRUE );
    RTMixLabel->setFont( RTMixLabel_font ); 
    RTMixLabel->setText( tr( "RTMix" ) );
    RTMixLabel->setAlignment( int( QLabel::AlignCenter ) );

    TuxLogo = new QLabel( tab_3, "TuxLogo" );
    TuxLogo->setGeometry( QRect( 10, 320, 50, 60 ) ); 
    TuxLogo->setPixmap( image4 );
    TuxLogo->setScaledContents( TRUE );
    QToolTip::add(  TuxLogo, tr( "Tux Logo" ) );
    TabWidget->insertTab( tab_3, tr( "About" ) );

    // tab order
    setTabOrder( TabWidget, SaveSettingsButton );
    setTabOrder( SaveSettingsButton, OKButton );
    setTabOrder( OKButton, ApplyButton );
    setTabOrder( ApplyButton, CancelButton );
    setTabOrder( CancelButton, DefaultsButton );
    setTabOrder( DefaultsButton, WhatsThisButton );
    setTabOrder( WhatsThisButton, Window1CheckBox );
    setTabOrder( Window1CheckBox, Window2CheckBox );
    setTabOrder( Window2CheckBox, Window3CheckBox );
    setTabOrder( Window3CheckBox, Window4CheckBox );
    setTabOrder( Window4CheckBox, Metro1CheckBox );
    setTabOrder( Metro1CheckBox, Metro2CheckBox );
    setTabOrder( Metro2CheckBox, Metro3CheckBox );
    setTabOrder( Metro3CheckBox, Metro4CheckBox );
    setTabOrder( Metro4CheckBox, LEDWindowCheckBox );
    setTabOrder( LEDWindowCheckBox, ExternalEditorLineEdit );
    setTabOrder( ExternalEditorLineEdit, ShortcutComboBox );
    setTabOrder( ShortcutComboBox, NewShortcutLineEdit );
    setTabOrder( NewShortcutLineEdit, DefaultShortcutButton );
    setTabOrder( DefaultShortcutButton, PixmapComboBox );
    setTabOrder( PixmapComboBox, OFFPixmapLineEdit );
    setTabOrder( OFFPixmapLineEdit, BrowseOFFButton );
    setTabOrder( BrowseOFFButton, ONPixmapLineEdit );
    setTabOrder( ONPixmapLineEdit, BrowseONButton );
    setTabOrder( BrowseONButton, WARNPixmapLineEdit );
    setTabOrder( WARNPixmapLineEdit, BrowseWARNButton );
    setTabOrder( BrowseWARNButton, DefaultPixmapButton );
    setTabOrder( DefaultPixmapButton, TimerComboBox );
    setTabOrder( TimerComboBox, SelectTimerColorBox );
    setTabOrder( SelectTimerColorBox, ResetTimerColorBox );
    setTabOrder( ResetTimerColorBox, GeneralFontRadio );
    setTabOrder( GeneralFontRadio, NotificationFontRadio );
    setTabOrder( NotificationFontRadio, EditorFontRadio );
    setTabOrder( EditorFontRadio, ExternalErrorFontRadio );
    setTabOrder( ExternalErrorFontRadio, WarningWindowFontRadio );
    setTabOrder( WarningWindowFontRadio, LEDWindowFontRadio );
    setTabOrder( LEDWindowFontRadio, SelectFontButton );
    setTabOrder( SelectFontButton, SelectColorButton );
    setTabOrder( SelectColorButton, DefaultFontButton );
    setTabOrder( DefaultFontButton, FontDemoMultiLineEdit );
    setTabOrder( FontDemoMultiLineEdit, MidiPortEdit );
    setTabOrder( MidiPortEdit, SpawnMidiButton );
    setTabOrder( SpawnMidiButton, NetAuthEdit );
    setTabOrder( NetAuthEdit, Filter );    
    setTabOrder( Filter, BrowserLineEdit );
    setTabOrder( BrowserLineEdit, ViewHelpButton );
    setTabOrder( ViewHelpButton, TabWidget );
    
	connect( MainWindowSizeGroup, SIGNAL ( pressed( int ) ), R, SLOT ( ToggleSize( int ) ) );
	//connect( R->T, SIGNAL ( Closed( int ) ), this, SLOT (ToggleExternErrorLog( int ) ) );

 	connect ( R->Window1, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleWarning1( int ) ) );
 	connect ( R->Window2, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleWarning2( int ) ) );
 	connect ( R->Window3, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleWarning3( int ) ) );
 	connect ( R->Window4, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleWarning4( int ) ) );

 	connect ( R->Metro1, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleMetro1( int ) ) );
 	connect ( R->Metro2, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleMetro2( int ) ) );
 	connect ( R->Metro3, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleMetro3( int ) ) );
 	connect ( R->Metro4, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleMetro4( int ) ) );

 	connect ( R->LEDw, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleLEDw( int ) ) );
	connect (R->E, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleTimer( int ) ) );
	connect (R->A, SIGNAL ( Closed( int ) ), this, SLOT ( ToggleAbsTimer( int ) ) );

	Current = new settingscue;
	Saved = new settingscue;
	Default = new settingscue;

	FillDefaultSettings();
	*Current = *Default;
	ReadSettings();

	AdjustShortcut( 0 );
    ApplyButton->setEnabled( FALSE );
}

/*  
 *  Destroys the object and frees any allocated resources
 */
settings::~settings()
{
    // no need to delete child widgets, Qt does it all for us
}

/*  
 *  Main event handler. Reimplemented to handle application
 *  font changes
 */
bool settings::event( QEvent* ev )
{
    bool ret = QWidget::event( ev ); 
    if ( ev->type() == QEvent::ApplicationFontChange ) {
	QFont WhatsThisButton_font(  WhatsThisButton->font() );
	WhatsThisButton_font.setPointSize( 9 );
	WhatsThisButton->setFont( WhatsThisButton_font ); 
	QFont FontDemoMultiLineEdit_font(  FontDemoMultiLineEdit->font() );
	FontDemoMultiLineEdit->setFont( FontDemoMultiLineEdit_font ); 
	QFont RTMixLabel_font(  RTMixLabel->font() );
	RTMixLabel_font.setPointSize( 12 );
	RTMixLabel_font.setBold( TRUE );
	RTMixLabel->setFont( RTMixLabel_font ); 
    }
    return ret;
}

void settings::closeEvent( QCloseEvent* e )
{
    ResetApplyButton();
    e->accept();
}

#include "settings-globals.h"
#include "settings-windowtoggles.h"
#include "settings-cuemethods.h"
#include "settings-pixmap.h"
#include "settings-lcds.h"
#include "settings-fonts.h"
#include "settings-names.h"
//#include "settings-help.h"
